# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.haptics
import winsdk.windows.devices.power
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.gaming.input.forcefeedback
import winsdk.windows.system

class ArcadeStickButtons(enum.IntFlag):
    NONE = 0
    STICK_UP = 0x1
    STICK_DOWN = 0x2
    STICK_LEFT = 0x4
    STICK_RIGHT = 0x8
    ACTION1 = 0x10
    ACTION2 = 0x20
    ACTION3 = 0x40
    ACTION4 = 0x80
    ACTION5 = 0x100
    ACTION6 = 0x200
    SPECIAL1 = 0x400
    SPECIAL2 = 0x800

class FlightStickButtons(enum.IntFlag):
    NONE = 0
    FIRE_PRIMARY = 0x1
    FIRE_SECONDARY = 0x2

class GameControllerButtonLabel(enum.IntEnum):
    NONE = 0
    XBOX_BACK = 1
    XBOX_START = 2
    XBOX_MENU = 3
    XBOX_VIEW = 4
    XBOX_UP = 5
    XBOX_DOWN = 6
    XBOX_LEFT = 7
    XBOX_RIGHT = 8
    XBOX_A = 9
    XBOX_B = 10
    XBOX_X = 11
    XBOX_Y = 12
    XBOX_LEFT_BUMPER = 13
    XBOX_LEFT_TRIGGER = 14
    XBOX_LEFT_STICK_BUTTON = 15
    XBOX_RIGHT_BUMPER = 16
    XBOX_RIGHT_TRIGGER = 17
    XBOX_RIGHT_STICK_BUTTON = 18
    XBOX_PADDLE1 = 19
    XBOX_PADDLE2 = 20
    XBOX_PADDLE3 = 21
    XBOX_PADDLE4 = 22
    MODE = 23
    SELECT = 24
    MENU = 25
    VIEW = 26
    BACK = 27
    START = 28
    OPTIONS = 29
    SHARE = 30
    UP = 31
    DOWN = 32
    LEFT = 33
    RIGHT = 34
    LETTER_A = 35
    LETTER_B = 36
    LETTER_C = 37
    LETTER_L = 38
    LETTER_R = 39
    LETTER_X = 40
    LETTER_Y = 41
    LETTER_Z = 42
    CROSS = 43
    CIRCLE = 44
    SQUARE = 45
    TRIANGLE = 46
    LEFT_BUMPER = 47
    LEFT_TRIGGER = 48
    LEFT_STICK_BUTTON = 49
    LEFT1 = 50
    LEFT2 = 51
    LEFT3 = 52
    RIGHT_BUMPER = 53
    RIGHT_TRIGGER = 54
    RIGHT_STICK_BUTTON = 55
    RIGHT1 = 56
    RIGHT2 = 57
    RIGHT3 = 58
    PADDLE1 = 59
    PADDLE2 = 60
    PADDLE3 = 61
    PADDLE4 = 62
    PLUS = 63
    MINUS = 64
    DOWN_LEFT_ARROW = 65
    DIAL_LEFT = 66
    DIAL_RIGHT = 67
    SUSPENSION = 68

class GameControllerSwitchKind(enum.IntEnum):
    TWO_WAY = 0
    FOUR_WAY = 1
    EIGHT_WAY = 2

class GameControllerSwitchPosition(enum.IntEnum):
    CENTER = 0
    UP = 1
    UP_RIGHT = 2
    RIGHT = 3
    DOWN_RIGHT = 4
    DOWN = 5
    DOWN_LEFT = 6
    LEFT = 7
    UP_LEFT = 8

class GamepadButtons(enum.IntFlag):
    NONE = 0
    MENU = 0x1
    VIEW = 0x2
    A = 0x4
    B = 0x8
    X = 0x10
    Y = 0x20
    D_PAD_UP = 0x40
    D_PAD_DOWN = 0x80
    D_PAD_LEFT = 0x100
    D_PAD_RIGHT = 0x200
    LEFT_SHOULDER = 0x400
    RIGHT_SHOULDER = 0x800
    LEFT_THUMBSTICK = 0x1000
    RIGHT_THUMBSTICK = 0x2000
    PADDLE1 = 0x4000
    PADDLE2 = 0x8000
    PADDLE3 = 0x10000
    PADDLE4 = 0x20000

class OptionalUINavigationButtons(enum.IntFlag):
    NONE = 0
    CONTEXT1 = 0x1
    CONTEXT2 = 0x2
    CONTEXT3 = 0x4
    CONTEXT4 = 0x8
    PAGE_UP = 0x10
    PAGE_DOWN = 0x20
    PAGE_LEFT = 0x40
    PAGE_RIGHT = 0x80
    SCROLL_UP = 0x100
    SCROLL_DOWN = 0x200
    SCROLL_LEFT = 0x400
    SCROLL_RIGHT = 0x800

class RacingWheelButtons(enum.IntFlag):
    NONE = 0
    PREVIOUS_GEAR = 0x1
    NEXT_GEAR = 0x2
    D_PAD_UP = 0x4
    D_PAD_DOWN = 0x8
    D_PAD_LEFT = 0x10
    D_PAD_RIGHT = 0x20
    BUTTON1 = 0x40
    BUTTON2 = 0x80
    BUTTON3 = 0x100
    BUTTON4 = 0x200
    BUTTON5 = 0x400
    BUTTON6 = 0x800
    BUTTON7 = 0x1000
    BUTTON8 = 0x2000
    BUTTON9 = 0x4000
    BUTTON10 = 0x8000
    BUTTON11 = 0x10000
    BUTTON12 = 0x20000
    BUTTON13 = 0x40000
    BUTTON14 = 0x80000
    BUTTON15 = 0x100000
    BUTTON16 = 0x200000

class RequiredUINavigationButtons(enum.IntFlag):
    NONE = 0
    MENU = 0x1
    VIEW = 0x2
    ACCEPT = 0x4
    CANCEL = 0x8
    UP = 0x10
    DOWN = 0x20
    LEFT = 0x40
    RIGHT = 0x80

Self = typing.TypeVar('Self')

class ArcadeStickReading:
    timestamp: winsdk.system.UInt64
    buttons: ArcadeStickButtons
    def __new__(cls: typing.Type[ArcadeStickReading], timestamp: winsdk.system.UInt64, buttons: ArcadeStickButtons) -> ArcadeStickReading: ...

class FlightStickReading:
    timestamp: winsdk.system.UInt64
    buttons: FlightStickButtons
    hat_switch: GameControllerSwitchPosition
    roll: winsdk.system.Double
    pitch: winsdk.system.Double
    yaw: winsdk.system.Double
    throttle: winsdk.system.Double
    def __new__(cls: typing.Type[FlightStickReading], timestamp: winsdk.system.UInt64, buttons: FlightStickButtons, hat_switch: GameControllerSwitchPosition, roll: winsdk.system.Double, pitch: winsdk.system.Double, yaw: winsdk.system.Double, throttle: winsdk.system.Double) -> FlightStickReading: ...

class GamepadReading:
    timestamp: winsdk.system.UInt64
    buttons: GamepadButtons
    left_trigger: winsdk.system.Double
    right_trigger: winsdk.system.Double
    left_thumbstick_x: winsdk.system.Double
    left_thumbstick_y: winsdk.system.Double
    right_thumbstick_x: winsdk.system.Double
    right_thumbstick_y: winsdk.system.Double
    def __new__(cls: typing.Type[GamepadReading], timestamp: winsdk.system.UInt64, buttons: GamepadButtons, left_trigger: winsdk.system.Double, right_trigger: winsdk.system.Double, left_thumbstick_x: winsdk.system.Double, left_thumbstick_y: winsdk.system.Double, right_thumbstick_x: winsdk.system.Double, right_thumbstick_y: winsdk.system.Double) -> GamepadReading: ...

class GamepadVibration:
    left_motor: winsdk.system.Double
    right_motor: winsdk.system.Double
    left_trigger: winsdk.system.Double
    right_trigger: winsdk.system.Double
    def __new__(cls: typing.Type[GamepadVibration], left_motor: winsdk.system.Double, right_motor: winsdk.system.Double, left_trigger: winsdk.system.Double, right_trigger: winsdk.system.Double) -> GamepadVibration: ...

class RacingWheelReading:
    timestamp: winsdk.system.UInt64
    buttons: RacingWheelButtons
    pattern_shifter_gear: winsdk.system.Int32
    wheel: winsdk.system.Double
    throttle: winsdk.system.Double
    brake: winsdk.system.Double
    clutch: winsdk.system.Double
    handbrake: winsdk.system.Double
    def __new__(cls: typing.Type[RacingWheelReading], timestamp: winsdk.system.UInt64, buttons: RacingWheelButtons, pattern_shifter_gear: winsdk.system.Int32, wheel: winsdk.system.Double, throttle: winsdk.system.Double, brake: winsdk.system.Double, clutch: winsdk.system.Double, handbrake: winsdk.system.Double) -> RacingWheelReading: ...

class UINavigationReading:
    timestamp: winsdk.system.UInt64
    required_buttons: RequiredUINavigationButtons
    optional_buttons: OptionalUINavigationButtons
    def __new__(cls: typing.Type[UINavigationReading], timestamp: winsdk.system.UInt64, required_buttons: RequiredUINavigationButtons, optional_buttons: OptionalUINavigationButtons) -> UINavigationReading: ...

class ArcadeStick(winsdk.system.Object):
    headset: typing.Optional[Headset]
    is_wireless: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    arcade_sticks: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[ArcadeStick]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ArcadeStick: ...
    @staticmethod
    def from_game_controller(game_controller: typing.Optional[IGameController]) -> typing.Optional[ArcadeStick]: ...
    def get_button_label(self, button: ArcadeStickButtons) -> GameControllerButtonLabel: ...
    def get_current_reading(self) -> ArcadeStickReading: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...
    def add_headset_connected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_connected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_headset_disconnected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_disconnected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_changed(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, winsdk.windows.system.UserChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_arcade_stick_added(value: winsdk.windows.foundation.EventHandler[ArcadeStick]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_arcade_stick_added(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_arcade_stick_removed(value: winsdk.windows.foundation.EventHandler[ArcadeStick]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_arcade_stick_removed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class FlightStick(winsdk.system.Object):
    hat_switch_kind: GameControllerSwitchKind
    headset: typing.Optional[Headset]
    is_wireless: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    flight_sticks: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[FlightStick]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FlightStick: ...
    @staticmethod
    def from_game_controller(game_controller: typing.Optional[IGameController]) -> typing.Optional[FlightStick]: ...
    def get_button_label(self, button: FlightStickButtons) -> GameControllerButtonLabel: ...
    def get_current_reading(self) -> FlightStickReading: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...
    def add_headset_connected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_connected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_headset_disconnected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_disconnected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_changed(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, winsdk.windows.system.UserChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_flight_stick_added(value: winsdk.windows.foundation.EventHandler[FlightStick]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_flight_stick_added(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_flight_stick_removed(value: winsdk.windows.foundation.EventHandler[FlightStick]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_flight_stick_removed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class Gamepad(winsdk.system.Object):
    headset: typing.Optional[Headset]
    is_wireless: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    vibration: GamepadVibration
    gamepads: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[Gamepad]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Gamepad: ...
    @staticmethod
    def from_game_controller(game_controller: typing.Optional[IGameController]) -> typing.Optional[Gamepad]: ...
    def get_button_label(self, button: GamepadButtons) -> GameControllerButtonLabel: ...
    def get_current_reading(self) -> GamepadReading: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...
    def add_headset_connected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_connected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_headset_disconnected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_disconnected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_changed(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, winsdk.windows.system.UserChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_gamepad_added(value: winsdk.windows.foundation.EventHandler[Gamepad]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_gamepad_added(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_gamepad_removed(value: winsdk.windows.foundation.EventHandler[Gamepad]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_gamepad_removed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class Headset(winsdk.system.Object):
    capture_device_id: str
    render_device_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Headset: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...

class RacingWheel(winsdk.system.Object):
    headset: typing.Optional[Headset]
    is_wireless: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    has_clutch: winsdk.system.Boolean
    has_handbrake: winsdk.system.Boolean
    has_pattern_shifter: winsdk.system.Boolean
    max_pattern_shifter_gear: winsdk.system.Int32
    max_wheel_angle: winsdk.system.Double
    wheel_motor: typing.Optional[winsdk.windows.gaming.input.forcefeedback.ForceFeedbackMotor]
    racing_wheels: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[RacingWheel]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RacingWheel: ...
    @staticmethod
    def from_game_controller(game_controller: typing.Optional[IGameController]) -> typing.Optional[RacingWheel]: ...
    def get_button_label(self, button: RacingWheelButtons) -> GameControllerButtonLabel: ...
    def get_current_reading(self) -> RacingWheelReading: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...
    def add_headset_connected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_connected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_headset_disconnected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_disconnected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_changed(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, winsdk.windows.system.UserChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_racing_wheel_added(value: winsdk.windows.foundation.EventHandler[RacingWheel]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_racing_wheel_added(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_racing_wheel_removed(value: winsdk.windows.foundation.EventHandler[RacingWheel]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_racing_wheel_removed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class RawGameController(winsdk.system.Object):
    headset: typing.Optional[Headset]
    is_wireless: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    axis_count: winsdk.system.Int32
    button_count: winsdk.system.Int32
    force_feedback_motors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.gaming.input.forcefeedback.ForceFeedbackMotor]]
    hardware_product_id: winsdk.system.UInt16
    hardware_vendor_id: winsdk.system.UInt16
    switch_count: winsdk.system.Int32
    display_name: str
    non_roamable_id: str
    simple_haptics_controllers: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.devices.haptics.SimpleHapticsController]]
    raw_game_controllers: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[RawGameController]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RawGameController: ...
    @staticmethod
    def from_game_controller(game_controller: typing.Optional[IGameController]) -> typing.Optional[RawGameController]: ...
    def get_button_label(self, button_index: winsdk.system.Int32) -> GameControllerButtonLabel: ...
    def get_current_reading(self, button_array: winsdk.system.Array[winsdk.system.Boolean], switch_array: winsdk.system.Array[GameControllerSwitchPosition], axis_array: winsdk.system.Array[winsdk.system.Double]) -> winsdk.system.UInt64: ...
    def get_switch_kind(self, switch_index: winsdk.system.Int32) -> GameControllerSwitchKind: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...
    def add_headset_connected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_connected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_headset_disconnected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_disconnected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_changed(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, winsdk.windows.system.UserChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_raw_game_controller_added(value: winsdk.windows.foundation.EventHandler[RawGameController]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_raw_game_controller_added(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_raw_game_controller_removed(value: winsdk.windows.foundation.EventHandler[RawGameController]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_raw_game_controller_removed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class UINavigationController(winsdk.system.Object):
    headset: typing.Optional[Headset]
    is_wireless: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    u_i_navigation_controllers: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[UINavigationController]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UINavigationController: ...
    @staticmethod
    def from_game_controller(game_controller: typing.Optional[IGameController]) -> typing.Optional[UINavigationController]: ...
    def get_current_reading(self) -> UINavigationReading: ...
    def get_optional_button_label(self, button: OptionalUINavigationButtons) -> GameControllerButtonLabel: ...
    def get_required_button_label(self, button: RequiredUINavigationButtons) -> GameControllerButtonLabel: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...
    def add_headset_connected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_connected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_headset_disconnected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_disconnected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_changed(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, winsdk.windows.system.UserChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_u_i_navigation_controller_added(value: winsdk.windows.foundation.EventHandler[UINavigationController]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_u_i_navigation_controller_added(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_u_i_navigation_controller_removed(value: winsdk.windows.foundation.EventHandler[UINavigationController]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_u_i_navigation_controller_removed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IGameController(winsdk.system.Object):
    headset: typing.Optional[Headset]
    is_wireless: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGameController: ...
    def add_headset_connected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_connected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_headset_disconnected(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, Headset]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_headset_disconnected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_user_changed(self, value: winsdk.windows.foundation.TypedEventHandler[IGameController, winsdk.windows.system.UserChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IGameControllerBatteryInfo(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGameControllerBatteryInfo: ...
    def try_get_battery_report(self) -> typing.Optional[winsdk.windows.devices.power.BatteryReport]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Graphics.DirectX.Direct3D11")

try:
    import winsdk.windows.graphics.directx
except ImportError:
    pass

class Direct3DBindings(enum.IntFlag):
    VERTEX_BUFFER = 0x1
    INDEX_BUFFER = 0x2
    CONSTANT_BUFFER = 0x4
    SHADER_RESOURCE = 0x8
    STREAM_OUTPUT = 0x10
    RENDER_TARGET = 0x20
    DEPTH_STENCIL = 0x40
    UNORDERED_ACCESS = 0x80
    DECODER = 0x200
    VIDEO_ENCODER = 0x400

class Direct3DUsage(enum.IntEnum):
    DEFAULT = 0
    IMMUTABLE = 1
    DYNAMIC = 2
    STAGING = 3

_ns_module._register_Direct3DBindings(Direct3DBindings)
_ns_module._register_Direct3DUsage(Direct3DUsage)

Direct3DMultisampleDescription = _ns_module.Direct3DMultisampleDescription
Direct3DSurfaceDescription = _ns_module.Direct3DSurfaceDescription
IDirect3DDevice = _ns_module.IDirect3DDevice
IDirect3DSurface = _ns_module.IDirect3DSurface



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Gaming.Preview.GamesEnumeration")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class GameListCategory(enum.IntEnum):
    CANDIDATE = 0
    CONFIRMED_BY_SYSTEM = 1
    CONFIRMED_BY_USER = 2

class GameListEntryLaunchableState(enum.IntEnum):
    NOT_LAUNCHABLE = 0
    BY_LAST_RUNNING_FULL_PATH = 1
    BY_USER_PROVIDED_PATH = 2
    BY_TILE = 3

_ns_module._register_GameListCategory(GameListCategory)
_ns_module._register_GameListEntryLaunchableState(GameListEntryLaunchableState)

GameList = _ns_module.GameList
GameListEntry = _ns_module.GameListEntry
GameModeConfiguration = _ns_module.GameModeConfiguration
GameModeUserConfiguration = _ns_module.GameModeUserConfiguration
IGameListEntry = _ns_module.IGameListEntry



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Contacts")

try:
    import winsdk.windows.data.text
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.ui.popups
except ImportError:
    pass

try:
    import winsdk.windows.ui.viewmanagement
except ImportError:
    pass

class ContactAddressKind(enum.IntEnum):
    HOME = 0
    WORK = 1
    OTHER = 2

class ContactAnnotationOperations(enum.IntFlag):
    NONE = 0
    CONTACT_PROFILE = 0x1
    MESSAGE = 0x2
    AUDIO_CALL = 0x4
    VIDEO_CALL = 0x8
    SOCIAL_FEEDS = 0x10
    SHARE = 0x20

class ContactAnnotationStoreAccessType(enum.IntEnum):
    APP_ANNOTATIONS_READ_WRITE = 0
    ALL_ANNOTATIONS_READ_WRITE = 1

class ContactBatchStatus(enum.IntEnum):
    SUCCESS = 0
    SERVER_SEARCH_SYNC_MANAGER_ERROR = 1
    SERVER_SEARCH_UNKNOWN_ERROR = 2

class ContactCardHeaderKind(enum.IntEnum):
    DEFAULT = 0
    BASIC = 1
    ENTERPRISE = 2

class ContactCardTabKind(enum.IntEnum):
    DEFAULT = 0
    EMAIL = 1
    MESSAGING = 2
    PHONE = 3
    VIDEO = 4
    ORGANIZATIONAL_HIERARCHY = 5

class ContactChangeType(enum.IntEnum):
    CREATED = 0
    MODIFIED = 1
    DELETED = 2
    CHANGE_TRACKING_LOST = 3

class ContactDateKind(enum.IntEnum):
    BIRTHDAY = 0
    ANNIVERSARY = 1
    OTHER = 2

class ContactEmailKind(enum.IntEnum):
    PERSONAL = 0
    WORK = 1
    OTHER = 2

class ContactFieldCategory(enum.IntEnum):
    NONE = 0
    HOME = 1
    WORK = 2
    MOBILE = 3
    OTHER = 4

class ContactFieldType(enum.IntEnum):
    EMAIL = 0
    PHONE_NUMBER = 1
    LOCATION = 2
    INSTANT_MESSAGE = 3
    CUSTOM = 4
    CONNECTED_SERVICE_ACCOUNT = 5
    IMPORTANT_DATE = 6
    ADDRESS = 7
    SIGNIFICANT_OTHER = 8
    NOTES = 9
    WEBSITE = 10
    JOB_INFO = 11

class ContactListOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    LIMITED = 1
    FULL = 2
    NONE = 3

class ContactListOtherAppWriteAccess(enum.IntEnum):
    NONE = 0
    SYSTEM_ONLY = 1
    LIMITED = 2

class ContactListSyncStatus(enum.IntEnum):
    IDLE = 0
    SYNCING = 1
    UP_TO_DATE = 2
    AUTHENTICATION_ERROR = 3
    POLICY_ERROR = 4
    UNKNOWN_ERROR = 5
    MANUAL_ACCOUNT_REMOVAL_REQUIRED = 6

class ContactMatchReasonKind(enum.IntEnum):
    NAME = 0
    EMAIL_ADDRESS = 1
    PHONE_NUMBER = 2
    JOB_INFO = 3
    YOMI_NAME = 4
    OTHER = 5

class ContactNameOrder(enum.IntEnum):
    FIRST_NAME_LAST_NAME = 0
    LAST_NAME_FIRST_NAME = 1

class ContactPhoneKind(enum.IntEnum):
    HOME = 0
    MOBILE = 1
    WORK = 2
    OTHER = 3
    PAGER = 4
    BUSINESS_FAX = 5
    HOME_FAX = 6
    COMPANY = 7
    ASSISTANT = 8
    RADIO = 9

class ContactQueryDesiredFields(enum.IntFlag):
    NONE = 0
    PHONE_NUMBER = 0x1
    EMAIL_ADDRESS = 0x2
    POSTAL_ADDRESS = 0x4

class ContactQuerySearchFields(enum.IntFlag):
    NONE = 0
    NAME = 0x1
    EMAIL = 0x2
    PHONE = 0x4
    ALL = 0xffffffff

class ContactQuerySearchScope(enum.IntEnum):
    LOCAL = 0
    SERVER = 1

class ContactRelationship(enum.IntEnum):
    OTHER = 0
    SPOUSE = 1
    PARTNER = 2
    SIBLING = 3
    PARENT = 4
    CHILD = 5

class ContactSelectionMode(enum.IntEnum):
    CONTACTS = 0
    FIELDS = 1

class ContactStoreAccessType(enum.IntEnum):
    APP_CONTACTS_READ_WRITE = 0
    ALL_CONTACTS_READ_ONLY = 1
    ALL_CONTACTS_READ_WRITE = 2

class PinnedContactSurface(enum.IntEnum):
    START_MENU = 0
    TASKBAR = 1

_ns_module._register_ContactAddressKind(ContactAddressKind)
_ns_module._register_ContactAnnotationOperations(ContactAnnotationOperations)
_ns_module._register_ContactAnnotationStoreAccessType(ContactAnnotationStoreAccessType)
_ns_module._register_ContactBatchStatus(ContactBatchStatus)
_ns_module._register_ContactCardHeaderKind(ContactCardHeaderKind)
_ns_module._register_ContactCardTabKind(ContactCardTabKind)
_ns_module._register_ContactChangeType(ContactChangeType)
_ns_module._register_ContactDateKind(ContactDateKind)
_ns_module._register_ContactEmailKind(ContactEmailKind)
_ns_module._register_ContactFieldCategory(ContactFieldCategory)
_ns_module._register_ContactFieldType(ContactFieldType)
_ns_module._register_ContactListOtherAppReadAccess(ContactListOtherAppReadAccess)
_ns_module._register_ContactListOtherAppWriteAccess(ContactListOtherAppWriteAccess)
_ns_module._register_ContactListSyncStatus(ContactListSyncStatus)
_ns_module._register_ContactMatchReasonKind(ContactMatchReasonKind)
_ns_module._register_ContactNameOrder(ContactNameOrder)
_ns_module._register_ContactPhoneKind(ContactPhoneKind)
_ns_module._register_ContactQueryDesiredFields(ContactQueryDesiredFields)
_ns_module._register_ContactQuerySearchFields(ContactQuerySearchFields)
_ns_module._register_ContactQuerySearchScope(ContactQuerySearchScope)
_ns_module._register_ContactRelationship(ContactRelationship)
_ns_module._register_ContactSelectionMode(ContactSelectionMode)
_ns_module._register_ContactStoreAccessType(ContactStoreAccessType)
_ns_module._register_PinnedContactSurface(PinnedContactSurface)

AggregateContactManager = _ns_module.AggregateContactManager
Contact = _ns_module.Contact
ContactAddress = _ns_module.ContactAddress
ContactAnnotation = _ns_module.ContactAnnotation
ContactAnnotationList = _ns_module.ContactAnnotationList
ContactAnnotationStore = _ns_module.ContactAnnotationStore
ContactBatch = _ns_module.ContactBatch
ContactCardDelayedDataLoader = _ns_module.ContactCardDelayedDataLoader
ContactCardOptions = _ns_module.ContactCardOptions
ContactChange = _ns_module.ContactChange
ContactChangeReader = _ns_module.ContactChangeReader
ContactChangeTracker = _ns_module.ContactChangeTracker
ContactChangedDeferral = _ns_module.ContactChangedDeferral
ContactChangedEventArgs = _ns_module.ContactChangedEventArgs
ContactConnectedServiceAccount = _ns_module.ContactConnectedServiceAccount
ContactDate = _ns_module.ContactDate
ContactEmail = _ns_module.ContactEmail
ContactField = _ns_module.ContactField
ContactFieldFactory = _ns_module.ContactFieldFactory
ContactGroup = _ns_module.ContactGroup
ContactInformation = _ns_module.ContactInformation
ContactInstantMessageField = _ns_module.ContactInstantMessageField
ContactJobInfo = _ns_module.ContactJobInfo
ContactLaunchActionVerbs = _ns_module.ContactLaunchActionVerbs
ContactList = _ns_module.ContactList
ContactListLimitedWriteOperations = _ns_module.ContactListLimitedWriteOperations
ContactListSyncConstraints = _ns_module.ContactListSyncConstraints
ContactListSyncManager = _ns_module.ContactListSyncManager
ContactLocationField = _ns_module.ContactLocationField
ContactManager = _ns_module.ContactManager
ContactManagerForUser = _ns_module.ContactManagerForUser
ContactMatchReason = _ns_module.ContactMatchReason
ContactPanel = _ns_module.ContactPanel
ContactPanelClosingEventArgs = _ns_module.ContactPanelClosingEventArgs
ContactPanelLaunchFullAppRequestedEventArgs = _ns_module.ContactPanelLaunchFullAppRequestedEventArgs
ContactPhone = _ns_module.ContactPhone
ContactPicker = _ns_module.ContactPicker
ContactQueryOptions = _ns_module.ContactQueryOptions
ContactQueryTextSearch = _ns_module.ContactQueryTextSearch
ContactReader = _ns_module.ContactReader
ContactSignificantOther = _ns_module.ContactSignificantOther
ContactStore = _ns_module.ContactStore
ContactStoreNotificationTriggerDetails = _ns_module.ContactStoreNotificationTriggerDetails
ContactWebsite = _ns_module.ContactWebsite
FullContactCardOptions = _ns_module.FullContactCardOptions
KnownContactField = _ns_module.KnownContactField
PinnedContactIdsQueryResult = _ns_module.PinnedContactIdsQueryResult
PinnedContactManager = _ns_module.PinnedContactManager
IContactField = _ns_module.IContactField
IContactFieldFactory = _ns_module.IContactFieldFactory
IContactInstantMessageFieldFactory = _ns_module.IContactInstantMessageFieldFactory
IContactLocationFieldFactory = _ns_module.IContactLocationFieldFactory



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices")

try:
    import winsdk.windows.devices.adc.provider
except ImportError:
    pass

try:
    import winsdk.windows.devices.gpio.provider
except ImportError:
    pass

try:
    import winsdk.windows.devices.i2c.provider
except ImportError:
    pass

try:
    import winsdk.windows.devices.pwm.provider
except ImportError:
    pass

try:
    import winsdk.windows.devices.spi.provider
except ImportError:
    pass


LowLevelDevicesAggregateProvider = _ns_module.LowLevelDevicesAggregateProvider
LowLevelDevicesController = _ns_module.LowLevelDevicesController
ILowLevelDevicesAggregateProvider = _ns_module.ILowLevelDevicesAggregateProvider



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.networking
import winsdk.windows.storage.streams

class XboxLiveEndpointPairCreationBehaviors(enum.IntFlag):
    NONE = 0
    REEVALUATE_PATH = 0x1

class XboxLiveEndpointPairCreationStatus(enum.IntEnum):
    SUCCEEDED = 0
    NO_LOCAL_NETWORKS = 1
    NO_COMPATIBLE_NETWORK_PATHS = 2
    LOCAL_SYSTEM_NOT_AUTHORIZED = 3
    CANCELED = 4
    TIMED_OUT = 5
    REMOTE_SYSTEM_NOT_AUTHORIZED = 6
    REFUSED_DUE_TO_CONFIGURATION = 7
    UNEXPECTED_INTERNAL_ERROR = 8

class XboxLiveEndpointPairState(enum.IntEnum):
    INVALID = 0
    CREATING_OUTBOUND = 1
    CREATING_INBOUND = 2
    READY = 3
    DELETING_LOCALLY = 4
    REMOTE_ENDPOINT_TERMINATING = 5
    DELETED = 6

class XboxLiveNetworkAccessKind(enum.IntEnum):
    OPEN = 0
    MODERATE = 1
    STRICT = 2

class XboxLiveQualityOfServiceMeasurementStatus(enum.IntEnum):
    NOT_STARTED = 0
    IN_PROGRESS = 1
    IN_PROGRESS_WITH_PROVISIONAL_RESULTS = 2
    SUCCEEDED = 3
    NO_LOCAL_NETWORKS = 4
    NO_COMPATIBLE_NETWORK_PATHS = 5
    LOCAL_SYSTEM_NOT_AUTHORIZED = 6
    CANCELED = 7
    TIMED_OUT = 8
    REMOTE_SYSTEM_NOT_AUTHORIZED = 9
    REFUSED_DUE_TO_CONFIGURATION = 10
    UNEXPECTED_INTERNAL_ERROR = 11

class XboxLiveQualityOfServiceMetric(enum.IntEnum):
    AVERAGE_LATENCY_IN_MILLISECONDS = 0
    MIN_LATENCY_IN_MILLISECONDS = 1
    MAX_LATENCY_IN_MILLISECONDS = 2
    AVERAGE_OUTBOUND_BITS_PER_SECOND = 3
    MIN_OUTBOUND_BITS_PER_SECOND = 4
    MAX_OUTBOUND_BITS_PER_SECOND = 5
    AVERAGE_INBOUND_BITS_PER_SECOND = 6
    MIN_INBOUND_BITS_PER_SECOND = 7
    MAX_INBOUND_BITS_PER_SECOND = 8

class XboxLiveSocketKind(enum.IntEnum):
    NONE = 0
    DATAGRAM = 1
    STREAM = 2

Self = typing.TypeVar('Self')

class XboxLiveDeviceAddress(winsdk.system.Object):
    is_local: winsdk.system.Boolean
    is_valid: winsdk.system.Boolean
    network_access_kind: XboxLiveNetworkAccessKind
    max_snapshot_bytes_size: typing.ClassVar[winsdk.system.UInt32]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveDeviceAddress: ...
    def compare(self, other_device_address: typing.Optional[XboxLiveDeviceAddress]) -> winsdk.system.Int32: ...
    @staticmethod
    def create_from_snapshot_base64(base64: str) -> typing.Optional[XboxLiveDeviceAddress]: ...
    @staticmethod
    def create_from_snapshot_buffer(buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[XboxLiveDeviceAddress]: ...
    @staticmethod
    def create_from_snapshot_bytes(buffer: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[XboxLiveDeviceAddress]: ...
    @staticmethod
    def get_local() -> typing.Optional[XboxLiveDeviceAddress]: ...
    def get_snapshot_as_base64(self) -> str: ...
    def get_snapshot_as_buffer(self) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    def get_snapshot_as_bytes(self, buffer: winsdk.system.Array[winsdk.system.UInt8]) -> winsdk.system.UInt32: ...
    def add_snapshot_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[XboxLiveDeviceAddress, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_snapshot_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class XboxLiveEndpointPair(winsdk.system.Object):
    local_host_name: typing.Optional[winsdk.windows.networking.HostName]
    local_port: str
    remote_device_address: typing.Optional[XboxLiveDeviceAddress]
    remote_host_name: typing.Optional[winsdk.windows.networking.HostName]
    remote_port: str
    state: XboxLiveEndpointPairState
    template: typing.Optional[XboxLiveEndpointPairTemplate]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveEndpointPair: ...
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def find_endpoint_pair_by_host_names_and_ports(local_host_name: typing.Optional[winsdk.windows.networking.HostName], local_port: str, remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_port: str) -> typing.Optional[XboxLiveEndpointPair]: ...
    @staticmethod
    def find_endpoint_pair_by_socket_address_bytes(local_socket_address: winsdk.system.Array[winsdk.system.UInt8], remote_socket_address: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[XboxLiveEndpointPair]: ...
    def get_local_socket_address_bytes(self, socket_address: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def get_remote_socket_address_bytes(self, socket_address: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def add_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[XboxLiveEndpointPair, XboxLiveEndpointPairStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class XboxLiveEndpointPairCreationResult(winsdk.system.Object):
    device_address: typing.Optional[XboxLiveDeviceAddress]
    endpoint_pair: typing.Optional[XboxLiveEndpointPair]
    is_existing_path_evaluation: winsdk.system.Boolean
    status: XboxLiveEndpointPairCreationStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveEndpointPairCreationResult: ...

class XboxLiveEndpointPairStateChangedEventArgs(winsdk.system.Object):
    new_state: XboxLiveEndpointPairState
    old_state: XboxLiveEndpointPairState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveEndpointPairStateChangedEventArgs: ...

class XboxLiveEndpointPairTemplate(winsdk.system.Object):
    acceptor_bound_port_range_lower: winsdk.system.UInt16
    acceptor_bound_port_range_upper: winsdk.system.UInt16
    endpoint_pairs: typing.Optional[winsdk.windows.foundation.collections.IVectorView[XboxLiveEndpointPair]]
    initiator_bound_port_range_lower: winsdk.system.UInt16
    initiator_bound_port_range_upper: winsdk.system.UInt16
    name: str
    socket_kind: XboxLiveSocketKind
    templates: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[XboxLiveEndpointPairTemplate]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveEndpointPairTemplate: ...
    @typing.overload
    def create_endpoint_pair_async(self, device_address: typing.Optional[XboxLiveDeviceAddress]) -> winsdk.windows.foundation.IAsyncOperation[XboxLiveEndpointPairCreationResult]: ...
    @typing.overload
    def create_endpoint_pair_async(self, device_address: typing.Optional[XboxLiveDeviceAddress], behaviors: XboxLiveEndpointPairCreationBehaviors) -> winsdk.windows.foundation.IAsyncOperation[XboxLiveEndpointPairCreationResult]: ...
    @typing.overload
    def create_endpoint_pair_for_ports_async(self, device_address: typing.Optional[XboxLiveDeviceAddress], initiator_port: str, acceptor_port: str) -> winsdk.windows.foundation.IAsyncOperation[XboxLiveEndpointPairCreationResult]: ...
    @typing.overload
    def create_endpoint_pair_for_ports_async(self, device_address: typing.Optional[XboxLiveDeviceAddress], initiator_port: str, acceptor_port: str, behaviors: XboxLiveEndpointPairCreationBehaviors) -> winsdk.windows.foundation.IAsyncOperation[XboxLiveEndpointPairCreationResult]: ...
    @staticmethod
    def get_template_by_name(name: str) -> typing.Optional[XboxLiveEndpointPairTemplate]: ...
    def add_inbound_endpoint_pair_created(self, handler: winsdk.windows.foundation.TypedEventHandler[XboxLiveEndpointPairTemplate, XboxLiveInboundEndpointPairCreatedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_inbound_endpoint_pair_created(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class XboxLiveInboundEndpointPairCreatedEventArgs(winsdk.system.Object):
    endpoint_pair: typing.Optional[XboxLiveEndpointPair]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveInboundEndpointPairCreatedEventArgs: ...

class XboxLiveQualityOfServiceMeasurement(winsdk.system.Object):
    timeout_in_milliseconds: winsdk.system.UInt32
    should_request_private_payloads: winsdk.system.Boolean
    number_of_probes_to_attempt: winsdk.system.UInt32
    device_addresses: typing.Optional[winsdk.windows.foundation.collections.IVector[XboxLiveDeviceAddress]]
    metric_results: typing.Optional[winsdk.windows.foundation.collections.IVectorView[XboxLiveQualityOfServiceMetricResult]]
    metrics: typing.Optional[winsdk.windows.foundation.collections.IVector[XboxLiveQualityOfServiceMetric]]
    number_of_results_pending: winsdk.system.UInt32
    private_payload_results: typing.Optional[winsdk.windows.foundation.collections.IVectorView[XboxLiveQualityOfServicePrivatePayloadResult]]
    published_private_payload: typing.ClassVar[typing.Optional[winsdk.windows.storage.streams.IBuffer]]
    max_simultaneous_probe_connections: typing.ClassVar[winsdk.system.UInt32]
    is_system_outbound_bandwidth_constrained: typing.ClassVar[winsdk.system.Boolean]
    is_system_inbound_bandwidth_constrained: typing.ClassVar[winsdk.system.Boolean]
    max_private_payload_size: typing.ClassVar[winsdk.system.UInt32]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveQualityOfServiceMeasurement: ...
    def __new__(cls: typing.Type[XboxLiveQualityOfServiceMeasurement]) -> XboxLiveQualityOfServiceMeasurement:...
    @staticmethod
    def clear_private_payload() -> None: ...
    def get_metric_result(self, device_address: typing.Optional[XboxLiveDeviceAddress], metric: XboxLiveQualityOfServiceMetric) -> typing.Optional[XboxLiveQualityOfServiceMetricResult]: ...
    def get_metric_results_for_device(self, device_address: typing.Optional[XboxLiveDeviceAddress]) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[XboxLiveQualityOfServiceMetricResult]]: ...
    def get_metric_results_for_metric(self, metric: XboxLiveQualityOfServiceMetric) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[XboxLiveQualityOfServiceMetricResult]]: ...
    def get_private_payload_result(self, device_address: typing.Optional[XboxLiveDeviceAddress]) -> typing.Optional[XboxLiveQualityOfServicePrivatePayloadResult]: ...
    def measure_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def publish_private_payload_bytes(payload: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...

class XboxLiveQualityOfServiceMetricResult(winsdk.system.Object):
    device_address: typing.Optional[XboxLiveDeviceAddress]
    metric: XboxLiveQualityOfServiceMetric
    status: XboxLiveQualityOfServiceMeasurementStatus
    value: winsdk.system.UInt64
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveQualityOfServiceMetricResult: ...

class XboxLiveQualityOfServicePrivatePayloadResult(winsdk.system.Object):
    device_address: typing.Optional[XboxLiveDeviceAddress]
    status: XboxLiveQualityOfServiceMeasurementStatus
    value: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XboxLiveQualityOfServicePrivatePayloadResult: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.MediaProperties")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.core
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class AudioEncodingQuality(enum.IntEnum):
    AUTO = 0
    HIGH = 1
    MEDIUM = 2
    LOW = 3

class MediaMirroringOptions(enum.IntFlag):
    NONE = 0
    HORIZONTAL = 0x1
    VERTICAL = 0x2

class MediaPixelFormat(enum.IntEnum):
    NV12 = 0
    BGRA8 = 1
    P010 = 2

class MediaRotation(enum.IntEnum):
    NONE = 0
    CLOCKWISE90_DEGREES = 1
    CLOCKWISE180_DEGREES = 2
    CLOCKWISE270_DEGREES = 3

class MediaThumbnailFormat(enum.IntEnum):
    BMP = 0
    BGRA8 = 1

class SphericalVideoFrameFormat(enum.IntEnum):
    NONE = 0
    UNSUPPORTED = 1
    EQUIRECTANGULAR = 2

class StereoscopicVideoPackingMode(enum.IntEnum):
    NONE = 0
    SIDE_BY_SIDE = 1
    TOP_BOTTOM = 2

class VideoEncodingQuality(enum.IntEnum):
    AUTO = 0
    H_D1080P = 1
    H_D720P = 2
    WVGA = 3
    NTSC = 4
    PAL = 5
    VGA = 6
    QVGA = 7
    UHD2160P = 8
    UHD4320P = 9

_ns_module._register_AudioEncodingQuality(AudioEncodingQuality)
_ns_module._register_MediaMirroringOptions(MediaMirroringOptions)
_ns_module._register_MediaPixelFormat(MediaPixelFormat)
_ns_module._register_MediaRotation(MediaRotation)
_ns_module._register_MediaThumbnailFormat(MediaThumbnailFormat)
_ns_module._register_SphericalVideoFrameFormat(SphericalVideoFrameFormat)
_ns_module._register_StereoscopicVideoPackingMode(StereoscopicVideoPackingMode)
_ns_module._register_VideoEncodingQuality(VideoEncodingQuality)

AudioEncodingProperties = _ns_module.AudioEncodingProperties
ContainerEncodingProperties = _ns_module.ContainerEncodingProperties
H264ProfileIds = _ns_module.H264ProfileIds
ImageEncodingProperties = _ns_module.ImageEncodingProperties
MediaEncodingProfile = _ns_module.MediaEncodingProfile
MediaEncodingSubtypes = _ns_module.MediaEncodingSubtypes
MediaPropertySet = _ns_module.MediaPropertySet
MediaRatio = _ns_module.MediaRatio
Mpeg2ProfileIds = _ns_module.Mpeg2ProfileIds
TimedMetadataEncodingProperties = _ns_module.TimedMetadataEncodingProperties
VideoEncodingProperties = _ns_module.VideoEncodingProperties
IMediaEncodingProperties = _ns_module.IMediaEncodingProperties



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Sensors")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics.display
except ImportError:
    pass

class AccelerometerReadingType(enum.IntEnum):
    STANDARD = 0
    LINEAR = 1
    GRAVITY = 2

class ActivitySensorReadingConfidence(enum.IntEnum):
    HIGH = 0
    LOW = 1

class ActivityType(enum.IntEnum):
    UNKNOWN = 0
    IDLE = 1
    STATIONARY = 2
    FIDGETING = 3
    WALKING = 4
    RUNNING = 5
    IN_VEHICLE = 6
    BIKING = 7

class HumanEngagement(enum.IntEnum):
    UNKNOWN = 0
    ENGAGED = 1
    UNENGAGED = 2

class HumanPresence(enum.IntEnum):
    UNKNOWN = 0
    PRESENT = 1
    NOT_PRESENT = 2

class MagnetometerAccuracy(enum.IntEnum):
    UNKNOWN = 0
    UNRELIABLE = 1
    APPROXIMATE = 2
    HIGH = 3

class PedometerStepKind(enum.IntEnum):
    UNKNOWN = 0
    WALKING = 1
    RUNNING = 2

class SensorOptimizationGoal(enum.IntEnum):
    PRECISION = 0
    POWER_EFFICIENCY = 1

class SensorReadingType(enum.IntEnum):
    ABSOLUTE = 0
    RELATIVE = 1

class SensorType(enum.IntEnum):
    ACCELEROMETER = 0
    ACTIVITY_SENSOR = 1
    BAROMETER = 2
    COMPASS = 3
    CUSTOM_SENSOR = 4
    GYROSCOPE = 5
    PROXIMITY_SENSOR = 6
    INCLINOMETER = 7
    LIGHT_SENSOR = 8
    ORIENTATION_SENSOR = 9
    PEDOMETER = 10
    RELATIVE_INCLINOMETER = 11
    RELATIVE_ORIENTATION_SENSOR = 12
    SIMPLE_ORIENTATION_SENSOR = 13

class SimpleOrientation(enum.IntEnum):
    NOT_ROTATED = 0
    ROTATED90_DEGREES_COUNTERCLOCKWISE = 1
    ROTATED180_DEGREES_COUNTERCLOCKWISE = 2
    ROTATED270_DEGREES_COUNTERCLOCKWISE = 3
    FACEUP = 4
    FACEDOWN = 5

_ns_module._register_AccelerometerReadingType(AccelerometerReadingType)
_ns_module._register_ActivitySensorReadingConfidence(ActivitySensorReadingConfidence)
_ns_module._register_ActivityType(ActivityType)
_ns_module._register_HumanEngagement(HumanEngagement)
_ns_module._register_HumanPresence(HumanPresence)
_ns_module._register_MagnetometerAccuracy(MagnetometerAccuracy)
_ns_module._register_PedometerStepKind(PedometerStepKind)
_ns_module._register_SensorOptimizationGoal(SensorOptimizationGoal)
_ns_module._register_SensorReadingType(SensorReadingType)
_ns_module._register_SensorType(SensorType)
_ns_module._register_SimpleOrientation(SimpleOrientation)

Accelerometer = _ns_module.Accelerometer
AccelerometerDataThreshold = _ns_module.AccelerometerDataThreshold
AccelerometerReading = _ns_module.AccelerometerReading
AccelerometerReadingChangedEventArgs = _ns_module.AccelerometerReadingChangedEventArgs
AccelerometerShakenEventArgs = _ns_module.AccelerometerShakenEventArgs
ActivitySensor = _ns_module.ActivitySensor
ActivitySensorReading = _ns_module.ActivitySensorReading
ActivitySensorReadingChangeReport = _ns_module.ActivitySensorReadingChangeReport
ActivitySensorReadingChangedEventArgs = _ns_module.ActivitySensorReadingChangedEventArgs
ActivitySensorTriggerDetails = _ns_module.ActivitySensorTriggerDetails
Altimeter = _ns_module.Altimeter
AltimeterReading = _ns_module.AltimeterReading
AltimeterReadingChangedEventArgs = _ns_module.AltimeterReadingChangedEventArgs
Barometer = _ns_module.Barometer
BarometerDataThreshold = _ns_module.BarometerDataThreshold
BarometerReading = _ns_module.BarometerReading
BarometerReadingChangedEventArgs = _ns_module.BarometerReadingChangedEventArgs
Compass = _ns_module.Compass
CompassDataThreshold = _ns_module.CompassDataThreshold
CompassReading = _ns_module.CompassReading
CompassReadingChangedEventArgs = _ns_module.CompassReadingChangedEventArgs
Gyrometer = _ns_module.Gyrometer
GyrometerDataThreshold = _ns_module.GyrometerDataThreshold
GyrometerReading = _ns_module.GyrometerReading
GyrometerReadingChangedEventArgs = _ns_module.GyrometerReadingChangedEventArgs
HingeAngleReading = _ns_module.HingeAngleReading
HingeAngleSensor = _ns_module.HingeAngleSensor
HingeAngleSensorReadingChangedEventArgs = _ns_module.HingeAngleSensorReadingChangedEventArgs
HumanPresenceFeatures = _ns_module.HumanPresenceFeatures
HumanPresenceSensor = _ns_module.HumanPresenceSensor
HumanPresenceSensorReading = _ns_module.HumanPresenceSensorReading
HumanPresenceSensorReadingChangedEventArgs = _ns_module.HumanPresenceSensorReadingChangedEventArgs
HumanPresenceSettings = _ns_module.HumanPresenceSettings
Inclinometer = _ns_module.Inclinometer
InclinometerDataThreshold = _ns_module.InclinometerDataThreshold
InclinometerReading = _ns_module.InclinometerReading
InclinometerReadingChangedEventArgs = _ns_module.InclinometerReadingChangedEventArgs
LightSensor = _ns_module.LightSensor
LightSensorDataThreshold = _ns_module.LightSensorDataThreshold
LightSensorReading = _ns_module.LightSensorReading
LightSensorReadingChangedEventArgs = _ns_module.LightSensorReadingChangedEventArgs
Magnetometer = _ns_module.Magnetometer
MagnetometerDataThreshold = _ns_module.MagnetometerDataThreshold
MagnetometerReading = _ns_module.MagnetometerReading
MagnetometerReadingChangedEventArgs = _ns_module.MagnetometerReadingChangedEventArgs
OrientationSensor = _ns_module.OrientationSensor
OrientationSensorReading = _ns_module.OrientationSensorReading
OrientationSensorReadingChangedEventArgs = _ns_module.OrientationSensorReadingChangedEventArgs
Pedometer = _ns_module.Pedometer
PedometerDataThreshold = _ns_module.PedometerDataThreshold
PedometerReading = _ns_module.PedometerReading
PedometerReadingChangedEventArgs = _ns_module.PedometerReadingChangedEventArgs
ProximitySensor = _ns_module.ProximitySensor
ProximitySensorDataThreshold = _ns_module.ProximitySensorDataThreshold
ProximitySensorDisplayOnOffController = _ns_module.ProximitySensorDisplayOnOffController
ProximitySensorReading = _ns_module.ProximitySensorReading
ProximitySensorReadingChangedEventArgs = _ns_module.ProximitySensorReadingChangedEventArgs
SensorDataThresholdTriggerDetails = _ns_module.SensorDataThresholdTriggerDetails
SensorQuaternion = _ns_module.SensorQuaternion
SensorRotationMatrix = _ns_module.SensorRotationMatrix
SimpleOrientationSensor = _ns_module.SimpleOrientationSensor
SimpleOrientationSensorOrientationChangedEventArgs = _ns_module.SimpleOrientationSensorOrientationChangedEventArgs
ISensorDataThreshold = _ns_module.ISensorDataThreshold



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.numerics

class ConditionForceEffectKind(enum.IntEnum):
    SPRING = 0
    DAMPER = 1
    INERTIA = 2
    FRICTION = 3

class ForceFeedbackEffectAxes(enum.IntFlag):
    NONE = 0
    X = 0x1
    Y = 0x2
    Z = 0x4

class ForceFeedbackEffectState(enum.IntEnum):
    STOPPED = 0
    RUNNING = 1
    PAUSED = 2
    FAULTED = 3

class ForceFeedbackLoadEffectResult(enum.IntEnum):
    SUCCEEDED = 0
    EFFECT_STORAGE_FULL = 1
    EFFECT_NOT_SUPPORTED = 2

class PeriodicForceEffectKind(enum.IntEnum):
    SQUARE_WAVE = 0
    SINE_WAVE = 1
    TRIANGLE_WAVE = 2
    SAWTOOTH_WAVE_UP = 3
    SAWTOOTH_WAVE_DOWN = 4

Self = typing.TypeVar('Self')

class ConditionForceEffect(winsdk.system.Object):
    kind: ConditionForceEffectKind
    gain: winsdk.system.Double
    state: ForceFeedbackEffectState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ConditionForceEffect: ...
    def __new__(cls: typing.Type[ConditionForceEffect], effect_kind: ConditionForceEffectKind) -> ConditionForceEffect:...
    def set_parameters(self, direction: winsdk.windows.foundation.numerics.Vector3, positive_coefficient: winsdk.system.Single, negative_coefficient: winsdk.system.Single, max_positive_magnitude: winsdk.system.Single, max_negative_magnitude: winsdk.system.Single, dead_zone: winsdk.system.Single, bias: winsdk.system.Single) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

class ConstantForceEffect(winsdk.system.Object):
    gain: winsdk.system.Double
    state: ForceFeedbackEffectState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ConstantForceEffect: ...
    def __new__(cls: typing.Type[ConstantForceEffect]) -> ConstantForceEffect:...
    def set_parameters(self, vector: winsdk.windows.foundation.numerics.Vector3, duration: datetime.timedelta) -> None: ...
    def set_parameters_with_envelope(self, vector: winsdk.windows.foundation.numerics.Vector3, attack_gain: winsdk.system.Single, sustain_gain: winsdk.system.Single, release_gain: winsdk.system.Single, start_delay: datetime.timedelta, attack_duration: datetime.timedelta, sustain_duration: datetime.timedelta, release_duration: datetime.timedelta, repeat_count: winsdk.system.UInt32) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

class ForceFeedbackMotor(winsdk.system.Object):
    master_gain: winsdk.system.Double
    are_effects_paused: winsdk.system.Boolean
    is_enabled: winsdk.system.Boolean
    supported_axes: ForceFeedbackEffectAxes
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ForceFeedbackMotor: ...
    def load_effect_async(self, effect: typing.Optional[IForceFeedbackEffect]) -> winsdk.windows.foundation.IAsyncOperation[ForceFeedbackLoadEffectResult]: ...
    def pause_all_effects(self) -> None: ...
    def resume_all_effects(self) -> None: ...
    def stop_all_effects(self) -> None: ...
    def try_disable_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_enable_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_reset_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_unload_effect_async(self, effect: typing.Optional[IForceFeedbackEffect]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class PeriodicForceEffect(winsdk.system.Object):
    gain: winsdk.system.Double
    state: ForceFeedbackEffectState
    kind: PeriodicForceEffectKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PeriodicForceEffect: ...
    def __new__(cls: typing.Type[PeriodicForceEffect], effect_kind: PeriodicForceEffectKind) -> PeriodicForceEffect:...
    def set_parameters(self, vector: winsdk.windows.foundation.numerics.Vector3, frequency: winsdk.system.Single, phase: winsdk.system.Single, bias: winsdk.system.Single, duration: datetime.timedelta) -> None: ...
    def set_parameters_with_envelope(self, vector: winsdk.windows.foundation.numerics.Vector3, frequency: winsdk.system.Single, phase: winsdk.system.Single, bias: winsdk.system.Single, attack_gain: winsdk.system.Single, sustain_gain: winsdk.system.Single, release_gain: winsdk.system.Single, start_delay: datetime.timedelta, attack_duration: datetime.timedelta, sustain_duration: datetime.timedelta, release_duration: datetime.timedelta, repeat_count: winsdk.system.UInt32) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

class RampForceEffect(winsdk.system.Object):
    gain: winsdk.system.Double
    state: ForceFeedbackEffectState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RampForceEffect: ...
    def __new__(cls: typing.Type[RampForceEffect]) -> RampForceEffect:...
    def set_parameters(self, start_vector: winsdk.windows.foundation.numerics.Vector3, end_vector: winsdk.windows.foundation.numerics.Vector3, duration: datetime.timedelta) -> None: ...
    def set_parameters_with_envelope(self, start_vector: winsdk.windows.foundation.numerics.Vector3, end_vector: winsdk.windows.foundation.numerics.Vector3, attack_gain: winsdk.system.Single, sustain_gain: winsdk.system.Single, release_gain: winsdk.system.Single, start_delay: datetime.timedelta, attack_duration: datetime.timedelta, sustain_duration: datetime.timedelta, release_duration: datetime.timedelta, repeat_count: winsdk.system.UInt32) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

class IForceFeedbackEffect(winsdk.system.Object):
    gain: winsdk.system.Double
    state: ForceFeedbackEffectState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IForceFeedbackEffect: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class BatteryStatus(enum.IntEnum):
    NOT_PRESENT = 0
    DISCHARGING = 1
    IDLE = 2
    CHARGING = 3

class EnergySaverStatus(enum.IntEnum):
    DISABLED = 0
    OFF = 1
    ON = 2

class PowerSupplyStatus(enum.IntEnum):
    NOT_PRESENT = 0
    INADEQUATE = 1
    ADEQUATE = 2

Self = typing.TypeVar('Self')

class BackgroundEnergyManager(winsdk.system.Object):
    excessive_usage_level: typing.ClassVar[winsdk.system.UInt32]
    low_usage_level: typing.ClassVar[winsdk.system.UInt32]
    max_acceptable_usage_level: typing.ClassVar[winsdk.system.UInt32]
    near_max_acceptable_usage_level: typing.ClassVar[winsdk.system.UInt32]
    near_termination_usage_level: typing.ClassVar[winsdk.system.UInt32]
    recent_energy_usage: typing.ClassVar[winsdk.system.UInt32]
    recent_energy_usage_level: typing.ClassVar[winsdk.system.UInt32]
    termination_usage_level: typing.ClassVar[winsdk.system.UInt32]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BackgroundEnergyManager: ...
    @staticmethod
    def add_recent_energy_usage_increased(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_recent_energy_usage_increased(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_recent_energy_usage_returned_to_low(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_recent_energy_usage_returned_to_low(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ForegroundEnergyManager(winsdk.system.Object):
    excessive_usage_level: typing.ClassVar[winsdk.system.UInt32]
    low_usage_level: typing.ClassVar[winsdk.system.UInt32]
    max_acceptable_usage_level: typing.ClassVar[winsdk.system.UInt32]
    near_max_acceptable_usage_level: typing.ClassVar[winsdk.system.UInt32]
    recent_energy_usage: typing.ClassVar[winsdk.system.UInt32]
    recent_energy_usage_level: typing.ClassVar[winsdk.system.UInt32]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ForegroundEnergyManager: ...
    @staticmethod
    def add_recent_energy_usage_increased(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_recent_energy_usage_increased(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_recent_energy_usage_returned_to_low(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_recent_energy_usage_returned_to_low(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PowerManager(winsdk.system.Object):
    battery_status: typing.ClassVar[BatteryStatus]
    energy_saver_status: typing.ClassVar[EnergySaverStatus]
    power_supply_status: typing.ClassVar[PowerSupplyStatus]
    remaining_charge_percent: typing.ClassVar[winsdk.system.Int32]
    remaining_discharge_time: typing.ClassVar[datetime.timedelta]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PowerManager: ...
    @staticmethod
    def add_battery_status_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_battery_status_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_energy_saver_status_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_energy_saver_status_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_power_supply_status_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_power_supply_status_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_remaining_charge_percent_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_remaining_charge_percent_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_remaining_discharge_time_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_remaining_discharge_time_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.management.deployment

class EnterpriseEnrollmentStatus(enum.IntEnum):
    SUCCESS = 0
    CANCELLED_BY_USER = 1
    UNKNOWN_FAILURE = 2

class EnterpriseStatus(enum.IntEnum):
    ENROLLED = 0
    DISABLED = 1
    REVOKED = 2
    EXPIRED = 3

Self = typing.TypeVar('Self')

class Enterprise(winsdk.system.Object):
    enrollment_valid_from: datetime.datetime
    enrollment_valid_to: datetime.datetime
    id: winsdk.system.Guid
    name: str
    status: EnterpriseStatus
    workplace_id: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Enterprise: ...

class EnterpriseEnrollmentManager(winsdk.system.Object):
    current_enterprise: typing.ClassVar[typing.Optional[Enterprise]]
    enrolled_enterprises: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[Enterprise]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnterpriseEnrollmentManager: ...
    @staticmethod
    def request_enrollment_async(enrollment_token: str) -> winsdk.windows.foundation.IAsyncOperation[EnterpriseEnrollmentResult]: ...
    @staticmethod
    def request_unenrollment_async(enterprise: typing.Optional[Enterprise]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def validate_enterprises_async() -> winsdk.windows.foundation.IAsyncAction: ...

class EnterpriseEnrollmentResult(winsdk.system.Object):
    enrolled_enterprise: typing.Optional[Enterprise]
    status: EnterpriseEnrollmentStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnterpriseEnrollmentResult: ...

class InstallationManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InstallationManager: ...
    @typing.overload
    @staticmethod
    def add_package_async(title: str, source_location: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[PackageInstallResult, winsdk.system.UInt32]: ...
    @typing.overload
    @staticmethod
    def add_package_async(title: str, source_location: typing.Optional[winsdk.windows.foundation.Uri], instance_id: str, offer_id: str, license: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[PackageInstallResult, winsdk.system.UInt32]: ...
    @typing.overload
    @staticmethod
    def find_packages() -> typing.Optional[winsdk.windows.foundation.collections.IIterable[winsdk.windows.applicationmodel.Package]]: ...
    @typing.overload
    @staticmethod
    def find_packages(package_name: str, package_publisher: str) -> typing.Optional[winsdk.windows.foundation.collections.IIterable[winsdk.windows.applicationmodel.Package]]: ...
    @staticmethod
    def find_packages_for_current_publisher() -> typing.Optional[winsdk.windows.foundation.collections.IIterable[winsdk.windows.applicationmodel.Package]]: ...
    @staticmethod
    def get_pending_package_installs() -> typing.Optional[winsdk.windows.foundation.collections.IIterable[winsdk.windows.foundation.IAsyncOperationWithProgress[PackageInstallResult, winsdk.system.UInt32]]]: ...
    @staticmethod
    def register_package_async(manifest_uri: typing.Optional[winsdk.windows.foundation.Uri], dependency_package_uris: typing.Iterable[winsdk.windows.foundation.Uri], deployment_options: winsdk.windows.management.deployment.DeploymentOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[PackageInstallResult, winsdk.system.UInt32]: ...
    @staticmethod
    def remove_package_async(package_full_name: str, removal_options: winsdk.windows.management.deployment.RemovalOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[PackageInstallResult, winsdk.system.UInt32]: ...

class PackageInstallResult(winsdk.system.Object):
    install_state: winsdk.windows.management.deployment.PackageInstallState
    product_id: str
    error_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PackageInstallResult: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Search")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass


LocalContentSuggestionSettings = _ns_module.LocalContentSuggestionSettings
SearchPane = _ns_module.SearchPane
SearchPaneQueryChangedEventArgs = _ns_module.SearchPaneQueryChangedEventArgs
SearchPaneQueryLinguisticDetails = _ns_module.SearchPaneQueryLinguisticDetails
SearchPaneQuerySubmittedEventArgs = _ns_module.SearchPaneQuerySubmittedEventArgs
SearchPaneResultSuggestionChosenEventArgs = _ns_module.SearchPaneResultSuggestionChosenEventArgs
SearchPaneSuggestionsRequest = _ns_module.SearchPaneSuggestionsRequest
SearchPaneSuggestionsRequestDeferral = _ns_module.SearchPaneSuggestionsRequestDeferral
SearchPaneSuggestionsRequestedEventArgs = _ns_module.SearchPaneSuggestionsRequestedEventArgs
SearchPaneVisibilityChangedEventArgs = _ns_module.SearchPaneVisibilityChangedEventArgs
SearchQueryLinguisticDetails = _ns_module.SearchQueryLinguisticDetails
SearchSuggestionCollection = _ns_module.SearchSuggestionCollection
SearchSuggestionsRequest = _ns_module.SearchSuggestionsRequest
SearchSuggestionsRequestDeferral = _ns_module.SearchSuggestionsRequestDeferral
ISearchPaneQueryChangedEventArgs = _ns_module.ISearchPaneQueryChangedEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.Import")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class PhotoImportAccessMode(enum.IntEnum):
    READ_WRITE = 0
    READ_ONLY = 1
    READ_AND_DELETE = 2

class PhotoImportConnectionTransport(enum.IntEnum):
    UNKNOWN = 0
    USB = 1
    I_P = 2
    BLUETOOTH = 3

class PhotoImportContentType(enum.IntEnum):
    UNKNOWN = 0
    IMAGE = 1
    VIDEO = 2

class PhotoImportContentTypeFilter(enum.IntEnum):
    ONLY_IMAGES = 0
    ONLY_VIDEOS = 1
    IMAGES_AND_VIDEOS = 2
    IMAGES_AND_VIDEOS_FROM_CAMERA_ROLL = 3

class PhotoImportImportMode(enum.IntEnum):
    IMPORT_EVERYTHING = 0
    IGNORE_SIDECARS = 1
    IGNORE_SIBLINGS = 2
    IGNORE_SIDECARS_AND_SIBLINGS = 3

class PhotoImportItemSelectionMode(enum.IntEnum):
    SELECT_ALL = 0
    SELECT_NONE = 1
    SELECT_NEW = 2

class PhotoImportPowerSource(enum.IntEnum):
    UNKNOWN = 0
    BATTERY = 1
    EXTERNAL = 2

class PhotoImportSourceType(enum.IntEnum):
    GENERIC = 0
    CAMERA = 1
    MEDIA_PLAYER = 2
    PHONE = 3
    VIDEO = 4
    PERSONAL_INFO_MANAGER = 5
    AUDIO_RECORDER = 6

class PhotoImportStage(enum.IntEnum):
    NOT_STARTED = 0
    FINDING_ITEMS = 1
    IMPORTING_ITEMS = 2
    DELETING_IMPORTED_ITEMS_FROM_SOURCE = 3

class PhotoImportStorageMediumType(enum.IntEnum):
    UNDEFINED = 0
    FIXED = 1
    REMOVABLE = 2

class PhotoImportSubfolderCreationMode(enum.IntEnum):
    DO_NOT_CREATE_SUBFOLDERS = 0
    CREATE_SUBFOLDERS_FROM_FILE_DATE = 1
    CREATE_SUBFOLDERS_FROM_EXIF_DATE = 2
    KEEP_ORIGINAL_FOLDER_STRUCTURE = 3

class PhotoImportSubfolderDateFormat(enum.IntEnum):
    YEAR = 0
    YEAR_MONTH = 1
    YEAR_MONTH_DAY = 2

_ns_module._register_PhotoImportAccessMode(PhotoImportAccessMode)
_ns_module._register_PhotoImportConnectionTransport(PhotoImportConnectionTransport)
_ns_module._register_PhotoImportContentType(PhotoImportContentType)
_ns_module._register_PhotoImportContentTypeFilter(PhotoImportContentTypeFilter)
_ns_module._register_PhotoImportImportMode(PhotoImportImportMode)
_ns_module._register_PhotoImportItemSelectionMode(PhotoImportItemSelectionMode)
_ns_module._register_PhotoImportPowerSource(PhotoImportPowerSource)
_ns_module._register_PhotoImportSourceType(PhotoImportSourceType)
_ns_module._register_PhotoImportStage(PhotoImportStage)
_ns_module._register_PhotoImportStorageMediumType(PhotoImportStorageMediumType)
_ns_module._register_PhotoImportSubfolderCreationMode(PhotoImportSubfolderCreationMode)
_ns_module._register_PhotoImportSubfolderDateFormat(PhotoImportSubfolderDateFormat)

PhotoImportProgress = _ns_module.PhotoImportProgress
PhotoImportDeleteImportedItemsFromSourceResult = _ns_module.PhotoImportDeleteImportedItemsFromSourceResult
PhotoImportFindItemsResult = _ns_module.PhotoImportFindItemsResult
PhotoImportImportItemsResult = _ns_module.PhotoImportImportItemsResult
PhotoImportItem = _ns_module.PhotoImportItem
PhotoImportItemImportedEventArgs = _ns_module.PhotoImportItemImportedEventArgs
PhotoImportManager = _ns_module.PhotoImportManager
PhotoImportOperation = _ns_module.PhotoImportOperation
PhotoImportSelectionChangedEventArgs = _ns_module.PhotoImportSelectionChangedEventArgs
PhotoImportSession = _ns_module.PhotoImportSession
PhotoImportSidecar = _ns_module.PhotoImportSidecar
PhotoImportSource = _ns_module.PhotoImportSource
PhotoImportStorageMedium = _ns_module.PhotoImportStorageMedium
PhotoImportVideoSegment = _ns_module.PhotoImportVideoSegment



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.geolocation
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.ui.popups

class ManeuverWarningKind(enum.IntEnum):
    NONE = 0
    ACCIDENT = 1
    ADMINISTRATIVE_DIVISION_CHANGE = 2
    ALERT = 3
    BLOCKED_ROAD = 4
    CHECK_TIMETABLE = 5
    CONGESTION = 6
    CONSTRUCTION = 7
    COUNTRY_CHANGE = 8
    DISABLED_VEHICLE = 9
    GATE_ACCESS = 10
    GET_OFF_TRANSIT = 11
    GET_ON_TRANSIT = 12
    ILLEGAL_U_TURN = 13
    MASS_TRANSIT = 14
    MISCELLANEOUS = 15
    NO_INCIDENT = 16
    OTHER = 17
    OTHER_NEWS = 18
    OTHER_TRAFFIC_INCIDENTS = 19
    PLANNED_EVENT = 20
    PRIVATE_ROAD = 21
    RESTRICTED_TURN = 22
    ROAD_CLOSURES = 23
    ROAD_HAZARD = 24
    SCHEDULED_CONSTRUCTION = 25
    SEASONAL_CLOSURES = 26
    TOLLBOOTH = 27
    TOLL_ROAD = 28
    TOLL_ZONE_ENTER = 29
    TOLL_ZONE_EXIT = 30
    TRAFFIC_FLOW = 31
    TRANSIT_LINE_CHANGE = 32
    UNPAVED_ROAD = 33
    UNSCHEDULED_CONSTRUCTION = 34
    WEATHER = 35

class ManeuverWarningSeverity(enum.IntEnum):
    NONE = 0
    LOW_IMPACT = 1
    MINOR = 2
    MODERATE = 3
    SERIOUS = 4

class MapLocationDesiredAccuracy(enum.IntEnum):
    HIGH = 0
    LOW = 1

class MapLocationFinderStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    BAD_LOCATION = 3
    INDEX_FAILURE = 4
    NETWORK_FAILURE = 5
    NOT_SUPPORTED = 6

class MapManeuverNotices(enum.IntFlag):
    NONE = 0
    TOLL = 0x1
    UNPAVED = 0x2

class MapRouteFinderStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    NO_ROUTE_FOUND = 3
    NO_ROUTE_FOUND_WITH_GIVEN_OPTIONS = 4
    START_POINT_NOT_FOUND = 5
    END_POINT_NOT_FOUND = 6
    NO_PEDESTRIAN_ROUTE_FOUND = 7
    NETWORK_FAILURE = 8
    NOT_SUPPORTED = 9

class MapRouteManeuverKind(enum.IntEnum):
    NONE = 0
    START = 1
    STOPOVER = 2
    STOPOVER_RESUME = 3
    END = 4
    GO_STRAIGHT = 5
    U_TURN_LEFT = 6
    U_TURN_RIGHT = 7
    TURN_KEEP_LEFT = 8
    TURN_KEEP_RIGHT = 9
    TURN_LIGHT_LEFT = 10
    TURN_LIGHT_RIGHT = 11
    TURN_LEFT = 12
    TURN_RIGHT = 13
    TURN_HARD_LEFT = 14
    TURN_HARD_RIGHT = 15
    FREEWAY_ENTER_LEFT = 16
    FREEWAY_ENTER_RIGHT = 17
    FREEWAY_LEAVE_LEFT = 18
    FREEWAY_LEAVE_RIGHT = 19
    FREEWAY_CONTINUE_LEFT = 20
    FREEWAY_CONTINUE_RIGHT = 21
    TRAFFIC_CIRCLE_LEFT = 22
    TRAFFIC_CIRCLE_RIGHT = 23
    TAKE_FERRY = 24

class MapRouteOptimization(enum.IntEnum):
    TIME = 0
    DISTANCE = 1
    TIME_WITH_TRAFFIC = 2
    SCENIC = 3

class MapRouteRestrictions(enum.IntFlag):
    NONE = 0
    HIGHWAYS = 0x1
    TOLL_ROADS = 0x2
    FERRIES = 0x4
    TUNNELS = 0x8
    DIRT_ROADS = 0x10
    MOTORAIL = 0x20

class MapServiceDataUsagePreference(enum.IntEnum):
    DEFAULT = 0
    OFFLINE_MAP_DATA_ONLY = 1

class TrafficCongestion(enum.IntEnum):
    UNKNOWN = 0
    LIGHT = 1
    MILD = 2
    MEDIUM = 3
    HEAVY = 4

class WaypointKind(enum.IntEnum):
    STOP = 0
    VIA = 1

Self = typing.TypeVar('Self')

class EnhancedWaypoint(winsdk.system.Object):
    kind: WaypointKind
    point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnhancedWaypoint: ...
    def __new__(cls: typing.Type[EnhancedWaypoint], point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], kind: WaypointKind) -> EnhancedWaypoint:...

class ManeuverWarning(winsdk.system.Object):
    kind: ManeuverWarningKind
    severity: ManeuverWarningSeverity
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ManeuverWarning: ...

class MapAddress(winsdk.system.Object):
    building_floor: str
    building_name: str
    building_room: str
    building_wing: str
    continent: str
    country: str
    country_code: str
    district: str
    neighborhood: str
    post_code: str
    region: str
    region_code: str
    street: str
    street_number: str
    town: str
    formatted_address: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapAddress: ...

class MapLocation(winsdk.system.Object):
    address: typing.Optional[MapAddress]
    description: str
    display_name: str
    point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapLocation: ...

class MapLocationFinder(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapLocationFinder: ...
    @typing.overload
    @staticmethod
    def find_locations_async(search_text: str, reference_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]) -> winsdk.windows.foundation.IAsyncOperation[MapLocationFinderResult]: ...
    @typing.overload
    @staticmethod
    def find_locations_async(search_text: str, reference_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], max_count: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[MapLocationFinderResult]: ...
    @typing.overload
    @staticmethod
    def find_locations_at_async(query_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]) -> winsdk.windows.foundation.IAsyncOperation[MapLocationFinderResult]: ...
    @typing.overload
    @staticmethod
    def find_locations_at_async(query_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], accuracy: MapLocationDesiredAccuracy) -> winsdk.windows.foundation.IAsyncOperation[MapLocationFinderResult]: ...

class MapLocationFinderResult(winsdk.system.Object):
    locations: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MapLocation]]
    status: MapLocationFinderStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapLocationFinderResult: ...

class MapManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapManager: ...
    @staticmethod
    def show_downloaded_maps_u_i() -> None: ...
    @staticmethod
    def show_maps_update_u_i() -> None: ...

class MapRoute(winsdk.system.Object):
    bounding_box: typing.Optional[winsdk.windows.devices.geolocation.GeoboundingBox]
    estimated_duration: datetime.timedelta
    is_traffic_based: winsdk.system.Boolean
    legs: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MapRouteLeg]]
    length_in_meters: winsdk.system.Double
    path: typing.Optional[winsdk.windows.devices.geolocation.Geopath]
    has_blocked_roads: winsdk.system.Boolean
    violated_restrictions: MapRouteRestrictions
    duration_without_traffic: datetime.timedelta
    traffic_congestion: TrafficCongestion
    is_scenic: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapRoute: ...

class MapRouteDrivingOptions(winsdk.system.Object):
    route_restrictions: MapRouteRestrictions
    route_optimization: MapRouteOptimization
    max_alternate_route_count: winsdk.system.UInt32
    initial_heading: typing.Optional[typing.Optional[winsdk.system.Double]]
    departure_time: typing.Optional[typing.Optional[datetime.datetime]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapRouteDrivingOptions: ...
    def __new__(cls: typing.Type[MapRouteDrivingOptions]) -> MapRouteDrivingOptions:...

class MapRouteFinder(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapRouteFinder: ...
    @typing.overload
    @staticmethod
    def get_driving_route_async(start_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], end_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_async(start_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], end_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], options: typing.Optional[MapRouteDrivingOptions]) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_async(start_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], end_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], optimization: MapRouteOptimization, restrictions: MapRouteRestrictions) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_async(start_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], end_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], optimization: MapRouteOptimization, restrictions: MapRouteRestrictions, heading_in_degrees: winsdk.system.Double) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_from_enhanced_waypoints_async(waypoints: typing.Iterable[EnhancedWaypoint]) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_from_enhanced_waypoints_async(waypoints: typing.Iterable[EnhancedWaypoint], options: typing.Optional[MapRouteDrivingOptions]) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_from_waypoints_async(way_points: typing.Iterable[winsdk.windows.devices.geolocation.Geopoint]) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_from_waypoints_async(way_points: typing.Iterable[winsdk.windows.devices.geolocation.Geopoint], optimization: MapRouteOptimization) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_from_waypoints_async(way_points: typing.Iterable[winsdk.windows.devices.geolocation.Geopoint], optimization: MapRouteOptimization, restrictions: MapRouteRestrictions) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @typing.overload
    @staticmethod
    def get_driving_route_from_waypoints_async(way_points: typing.Iterable[winsdk.windows.devices.geolocation.Geopoint], optimization: MapRouteOptimization, restrictions: MapRouteRestrictions, heading_in_degrees: winsdk.system.Double) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @staticmethod
    def get_walking_route_async(start_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], end_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...
    @staticmethod
    def get_walking_route_from_waypoints_async(way_points: typing.Iterable[winsdk.windows.devices.geolocation.Geopoint]) -> winsdk.windows.foundation.IAsyncOperation[MapRouteFinderResult]: ...

class MapRouteFinderResult(winsdk.system.Object):
    route: typing.Optional[MapRoute]
    status: MapRouteFinderStatus
    alternate_routes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MapRoute]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapRouteFinderResult: ...

class MapRouteLeg(winsdk.system.Object):
    bounding_box: typing.Optional[winsdk.windows.devices.geolocation.GeoboundingBox]
    estimated_duration: datetime.timedelta
    length_in_meters: winsdk.system.Double
    maneuvers: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MapRouteManeuver]]
    path: typing.Optional[winsdk.windows.devices.geolocation.Geopath]
    duration_without_traffic: datetime.timedelta
    traffic_congestion: TrafficCongestion
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapRouteLeg: ...

class MapRouteManeuver(winsdk.system.Object):
    exit_number: str
    instruction_text: str
    kind: MapRouteManeuverKind
    length_in_meters: winsdk.system.Double
    maneuver_notices: MapManeuverNotices
    starting_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]
    end_heading: winsdk.system.Double
    start_heading: winsdk.system.Double
    street_name: str
    warnings: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ManeuverWarning]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapRouteManeuver: ...

class MapService(winsdk.system.Object):
    service_token: typing.ClassVar[str]
    world_view_region_code: typing.ClassVar[str]
    data_attributions: typing.ClassVar[str]
    data_usage_preference: typing.ClassVar[MapServiceDataUsagePreference]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MapService: ...

class PlaceInfo(winsdk.system.Object):
    display_address: str
    display_name: str
    geoshape: typing.Optional[winsdk.windows.devices.geolocation.IGeoshape]
    identifier: str
    is_show_supported: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaceInfo: ...
    @typing.overload
    @staticmethod
    def create(reference_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]) -> typing.Optional[PlaceInfo]: ...
    @typing.overload
    @staticmethod
    def create(reference_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], options: typing.Optional[PlaceInfoCreateOptions]) -> typing.Optional[PlaceInfo]: ...
    @typing.overload
    @staticmethod
    def create_from_address(display_address: str) -> typing.Optional[PlaceInfo]: ...
    @typing.overload
    @staticmethod
    def create_from_address(display_address: str, display_name: str) -> typing.Optional[PlaceInfo]: ...
    @typing.overload
    @staticmethod
    def create_from_identifier(identifier: str) -> typing.Optional[PlaceInfo]: ...
    @typing.overload
    @staticmethod
    def create_from_identifier(identifier: str, default_point: typing.Optional[winsdk.windows.devices.geolocation.Geopoint], options: typing.Optional[PlaceInfoCreateOptions]) -> typing.Optional[PlaceInfo]: ...
    @staticmethod
    def create_from_map_location(location: typing.Optional[MapLocation]) -> typing.Optional[PlaceInfo]: ...
    @typing.overload
    def show(self, selection: winsdk.windows.foundation.Rect) -> None: ...
    @typing.overload
    def show(self, selection: winsdk.windows.foundation.Rect, preferred_placement: winsdk.windows.ui.popups.Placement) -> None: ...

class PlaceInfoCreateOptions(winsdk.system.Object):
    display_name: str
    display_address: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaceInfoCreateOptions: ...
    def __new__(cls: typing.Type[PlaceInfoCreateOptions]) -> PlaceInfoCreateOptions:...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Usb")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class UsbControlRecipient(enum.IntEnum):
    DEVICE = 0
    SPECIFIED_INTERFACE = 1
    ENDPOINT = 2
    OTHER = 3
    DEFAULT_INTERFACE = 4

class UsbControlTransferType(enum.IntEnum):
    STANDARD = 0
    CLASS = 1
    VENDOR = 2

class UsbEndpointType(enum.IntEnum):
    CONTROL = 0
    ISOCHRONOUS = 1
    BULK = 2
    INTERRUPT = 3

class UsbReadOptions(enum.IntFlag):
    NONE = 0
    AUTO_CLEAR_STALL = 0x1
    OVERRIDE_AUTOMATIC_BUFFER_MANAGEMENT = 0x2
    IGNORE_SHORT_PACKET = 0x4
    ALLOW_PARTIAL_READS = 0x8

class UsbTransferDirection(enum.IntEnum):
    OUT = 0
    IN = 1

class UsbWriteOptions(enum.IntFlag):
    NONE = 0
    AUTO_CLEAR_STALL = 0x1
    SHORT_PACKET_TERMINATE = 0x2

_ns_module._register_UsbControlRecipient(UsbControlRecipient)
_ns_module._register_UsbControlTransferType(UsbControlTransferType)
_ns_module._register_UsbEndpointType(UsbEndpointType)
_ns_module._register_UsbReadOptions(UsbReadOptions)
_ns_module._register_UsbTransferDirection(UsbTransferDirection)
_ns_module._register_UsbWriteOptions(UsbWriteOptions)

UsbBulkInEndpointDescriptor = _ns_module.UsbBulkInEndpointDescriptor
UsbBulkInPipe = _ns_module.UsbBulkInPipe
UsbBulkOutEndpointDescriptor = _ns_module.UsbBulkOutEndpointDescriptor
UsbBulkOutPipe = _ns_module.UsbBulkOutPipe
UsbConfiguration = _ns_module.UsbConfiguration
UsbConfigurationDescriptor = _ns_module.UsbConfigurationDescriptor
UsbControlRequestType = _ns_module.UsbControlRequestType
UsbDescriptor = _ns_module.UsbDescriptor
UsbDevice = _ns_module.UsbDevice
UsbDeviceClass = _ns_module.UsbDeviceClass
UsbDeviceClasses = _ns_module.UsbDeviceClasses
UsbDeviceDescriptor = _ns_module.UsbDeviceDescriptor
UsbEndpointDescriptor = _ns_module.UsbEndpointDescriptor
UsbInterface = _ns_module.UsbInterface
UsbInterfaceDescriptor = _ns_module.UsbInterfaceDescriptor
UsbInterfaceSetting = _ns_module.UsbInterfaceSetting
UsbInterruptInEndpointDescriptor = _ns_module.UsbInterruptInEndpointDescriptor
UsbInterruptInEventArgs = _ns_module.UsbInterruptInEventArgs
UsbInterruptInPipe = _ns_module.UsbInterruptInPipe
UsbInterruptOutEndpointDescriptor = _ns_module.UsbInterruptOutEndpointDescriptor
UsbInterruptOutPipe = _ns_module.UsbInterruptOutPipe
UsbSetupPacket = _ns_module.UsbSetupPacket



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.credentials
import winsdk.windows.system

class FindAllWebAccountsStatus(enum.IntEnum):
    SUCCESS = 0
    NOT_ALLOWED_BY_PROVIDER = 1
    NOT_SUPPORTED_BY_PROVIDER = 2
    PROVIDER_ERROR = 3

class WebTokenRequestPromptType(enum.IntEnum):
    DEFAULT = 0
    FORCE_AUTHENTICATION = 1

class WebTokenRequestStatus(enum.IntEnum):
    SUCCESS = 0
    USER_CANCEL = 1
    ACCOUNT_SWITCH = 2
    USER_INTERACTION_REQUIRED = 3
    ACCOUNT_PROVIDER_NOT_AVAILABLE = 4
    PROVIDER_ERROR = 5

Self = typing.TypeVar('Self')

class FindAllAccountsResult(winsdk.system.Object):
    accounts: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.credentials.WebAccount]]
    provider_error: typing.Optional[WebProviderError]
    status: FindAllWebAccountsStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FindAllAccountsResult: ...

class WebAccountEventArgs(winsdk.system.Object):
    account: typing.Optional[winsdk.windows.security.credentials.WebAccount]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountEventArgs: ...

class WebAccountMonitor(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountMonitor: ...
    def add_default_sign_in_account_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[WebAccountMonitor, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_default_sign_in_account_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_removed(self, handler: winsdk.windows.foundation.TypedEventHandler[WebAccountMonitor, WebAccountEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_removed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_updated(self, handler: winsdk.windows.foundation.TypedEventHandler[WebAccountMonitor, WebAccountEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_updated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_account_picture_updated(self, handler: winsdk.windows.foundation.TypedEventHandler[WebAccountMonitor, WebAccountEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_account_picture_updated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WebAuthenticationCoreManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAuthenticationCoreManager: ...
    @staticmethod
    def create_web_account_monitor(web_accounts: typing.Iterable[winsdk.windows.security.credentials.WebAccount]) -> typing.Optional[WebAccountMonitor]: ...
    @staticmethod
    def find_account_async(provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider], web_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @typing.overload
    @staticmethod
    def find_account_provider_async(web_account_provider_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccountProvider]: ...
    @typing.overload
    @staticmethod
    def find_account_provider_async(web_account_provider_id: str, authority: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccountProvider]: ...
    @typing.overload
    @staticmethod
    def find_account_provider_async(web_account_provider_id: str, authority: str, user: typing.Optional[winsdk.windows.system.User]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccountProvider]: ...
    @typing.overload
    @staticmethod
    def find_all_accounts_async(provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider]) -> winsdk.windows.foundation.IAsyncOperation[FindAllAccountsResult]: ...
    @typing.overload
    @staticmethod
    def find_all_accounts_async(provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider], client_id: str) -> winsdk.windows.foundation.IAsyncOperation[FindAllAccountsResult]: ...
    @typing.overload
    @staticmethod
    def find_system_account_provider_async(web_account_provider_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccountProvider]: ...
    @typing.overload
    @staticmethod
    def find_system_account_provider_async(web_account_provider_id: str, authority: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccountProvider]: ...
    @typing.overload
    @staticmethod
    def find_system_account_provider_async(web_account_provider_id: str, authority: str, user: typing.Optional[winsdk.windows.system.User]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccountProvider]: ...
    @typing.overload
    @staticmethod
    def get_token_silently_async(request: typing.Optional[WebTokenRequest]) -> winsdk.windows.foundation.IAsyncOperation[WebTokenRequestResult]: ...
    @typing.overload
    @staticmethod
    def get_token_silently_async(request: typing.Optional[WebTokenRequest], web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncOperation[WebTokenRequestResult]: ...
    @typing.overload
    @staticmethod
    def request_token_async(request: typing.Optional[WebTokenRequest]) -> winsdk.windows.foundation.IAsyncOperation[WebTokenRequestResult]: ...
    @typing.overload
    @staticmethod
    def request_token_async(request: typing.Optional[WebTokenRequest], web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncOperation[WebTokenRequestResult]: ...

class WebProviderError(winsdk.system.Object):
    error_code: winsdk.system.UInt32
    error_message: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebProviderError: ...
    def __new__(cls: typing.Type[WebProviderError], error_code: winsdk.system.UInt32, error_message: str) -> WebProviderError:...

class WebTokenRequest(winsdk.system.Object):
    client_id: str
    prompt_type: WebTokenRequestPromptType
    properties: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    scope: str
    web_account_provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider]
    app_properties: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    correlation_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebTokenRequest: ...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenRequest], provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider], scope: str, client_id: str) -> WebTokenRequest:...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenRequest], provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider], scope: str, client_id: str, prompt_type: WebTokenRequestPromptType) -> WebTokenRequest:...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenRequest], provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider]) -> WebTokenRequest:...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenRequest], provider: typing.Optional[winsdk.windows.security.credentials.WebAccountProvider], scope: str) -> WebTokenRequest:...

class WebTokenRequestResult(winsdk.system.Object):
    response_data: typing.Optional[winsdk.windows.foundation.collections.IVectorView[WebTokenResponse]]
    response_error: typing.Optional[WebProviderError]
    response_status: WebTokenRequestStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebTokenRequestResult: ...
    def invalidate_cache_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class WebTokenResponse(winsdk.system.Object):
    properties: typing.Optional[winsdk.windows.foundation.collections.IMap[str, str]]
    provider_error: typing.Optional[WebProviderError]
    token: str
    web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebTokenResponse: ...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenResponse], token: str) -> WebTokenResponse:...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenResponse], token: str, web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> WebTokenResponse:...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenResponse], token: str, web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount], error: typing.Optional[WebProviderError]) -> WebTokenResponse:...
    @typing.overload
    def __new__(cls: typing.Type[WebTokenResponse]) -> WebTokenResponse:...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Networking.Connectivity")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.networking
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class CellularApnAuthenticationType(enum.IntEnum):
    NONE = 0
    PAP = 1
    CHAP = 2
    MSCHAPV2 = 3

class ConnectionProfileDeleteStatus(enum.IntEnum):
    SUCCESS = 0
    DENIED_BY_USER = 1
    DENIED_BY_SYSTEM = 2
    UNKNOWN_ERROR = 3

class DataUsageGranularity(enum.IntEnum):
    PER_MINUTE = 0
    PER_HOUR = 1
    PER_DAY = 2
    TOTAL = 3

class DomainAuthenticationKind(enum.IntEnum):
    NONE = 0
    LDAP = 1
    TLS = 2

class DomainConnectivityLevel(enum.IntEnum):
    NONE = 0
    UNAUTHENTICATED = 1
    AUTHENTICATED = 2

class NetworkAuthenticationType(enum.IntEnum):
    NONE = 0
    UNKNOWN = 1
    OPEN80211 = 2
    SHARED_KEY80211 = 3
    WPA = 4
    WPA_PSK = 5
    WPA_NONE = 6
    RSNA = 7
    RSNA_PSK = 8
    IHV = 9
    WPA3 = 10
    WPA3_ENTERPRISE192_BITS = 10
    WPA3_SAE = 11
    OWE = 12
    WPA3_ENTERPRISE = 13

class NetworkConnectivityLevel(enum.IntEnum):
    NONE = 0
    LOCAL_ACCESS = 1
    CONSTRAINED_INTERNET_ACCESS = 2
    INTERNET_ACCESS = 3

class NetworkCostType(enum.IntEnum):
    UNKNOWN = 0
    UNRESTRICTED = 1
    FIXED = 2
    VARIABLE = 3

class NetworkEncryptionType(enum.IntEnum):
    NONE = 0
    UNKNOWN = 1
    WEP = 2
    WEP40 = 3
    WEP104 = 4
    TKIP = 5
    CCMP = 6
    WPA_USE_GROUP = 7
    RSN_USE_GROUP = 8
    IHV = 9
    GCMP = 10
    GCMP256 = 11

class NetworkTypes(enum.IntFlag):
    NONE = 0
    INTERNET = 0x1
    PRIVATE_NETWORK = 0x2

class RoamingStates(enum.IntFlag):
    NONE = 0
    NOT_ROAMING = 0x1
    ROAMING = 0x2

class TriStates(enum.IntEnum):
    DO_NOT_CARE = 0
    NO = 1
    YES = 2

class WwanDataClass(enum.IntFlag):
    NONE = 0
    GPRS = 0x1
    EDGE = 0x2
    UMTS = 0x4
    HSDPA = 0x8
    HSUPA = 0x10
    LTE_ADVANCED = 0x20
    CDMA1X_RTT = 0x10000
    CDMA1X_EVDO = 0x20000
    CDMA1X_EVDO_REV_A = 0x40000
    CDMA1X_EVDV = 0x80000
    CDMA3X_RTT = 0x100000
    CDMA1X_EVDO_REV_B = 0x200000
    CDMA_UMB = 0x400000
    CUSTOM = 0x80000000

class WwanNetworkIPKind(enum.IntEnum):
    NONE = 0
    IPV4 = 1
    IPV6 = 2
    IPV4V6 = 3
    IPV4V6V4_XLAT = 4

class WwanNetworkRegistrationState(enum.IntEnum):
    NONE = 0
    DEREGISTERED = 1
    SEARCHING = 2
    HOME = 3
    ROAMING = 4
    PARTNER = 5
    DENIED = 6

_ns_module._register_CellularApnAuthenticationType(CellularApnAuthenticationType)
_ns_module._register_ConnectionProfileDeleteStatus(ConnectionProfileDeleteStatus)
_ns_module._register_DataUsageGranularity(DataUsageGranularity)
_ns_module._register_DomainAuthenticationKind(DomainAuthenticationKind)
_ns_module._register_DomainConnectivityLevel(DomainConnectivityLevel)
_ns_module._register_NetworkAuthenticationType(NetworkAuthenticationType)
_ns_module._register_NetworkConnectivityLevel(NetworkConnectivityLevel)
_ns_module._register_NetworkCostType(NetworkCostType)
_ns_module._register_NetworkEncryptionType(NetworkEncryptionType)
_ns_module._register_NetworkTypes(NetworkTypes)
_ns_module._register_RoamingStates(RoamingStates)
_ns_module._register_TriStates(TriStates)
_ns_module._register_WwanDataClass(WwanDataClass)
_ns_module._register_WwanNetworkIPKind(WwanNetworkIPKind)
_ns_module._register_WwanNetworkRegistrationState(WwanNetworkRegistrationState)

NetworkUsageStates = _ns_module.NetworkUsageStates
AttributedNetworkUsage = _ns_module.AttributedNetworkUsage
CellularApnContext = _ns_module.CellularApnContext
ConnectionCost = _ns_module.ConnectionCost
ConnectionProfile = _ns_module.ConnectionProfile
ConnectionProfileFilter = _ns_module.ConnectionProfileFilter
ConnectionSession = _ns_module.ConnectionSession
ConnectivityInterval = _ns_module.ConnectivityInterval
ConnectivityManager = _ns_module.ConnectivityManager
DataPlanStatus = _ns_module.DataPlanStatus
DataPlanUsage = _ns_module.DataPlanUsage
DataUsage = _ns_module.DataUsage
IPInformation = _ns_module.IPInformation
LanIdentifier = _ns_module.LanIdentifier
LanIdentifierData = _ns_module.LanIdentifierData
NetworkAdapter = _ns_module.NetworkAdapter
NetworkInformation = _ns_module.NetworkInformation
NetworkItem = _ns_module.NetworkItem
NetworkSecuritySettings = _ns_module.NetworkSecuritySettings
NetworkStateChangeEventDetails = _ns_module.NetworkStateChangeEventDetails
NetworkUsage = _ns_module.NetworkUsage
ProviderNetworkUsage = _ns_module.ProviderNetworkUsage
ProxyConfiguration = _ns_module.ProxyConfiguration
RoutePolicy = _ns_module.RoutePolicy
WlanConnectionProfileDetails = _ns_module.WlanConnectionProfileDetails
WwanConnectionProfileDetails = _ns_module.WwanConnectionProfileDetails



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.credentials
import winsdk.windows.system
import winsdk.windows.ui
import winsdk.windows.ui.shell

class UserActivityState(enum.IntEnum):
    NEW = 0
    PUBLISHED = 1

Self = typing.TypeVar('Self')

class UserActivity(winsdk.system.Object):
    fallback_uri: typing.Optional[winsdk.windows.foundation.Uri]
    content_uri: typing.Optional[winsdk.windows.foundation.Uri]
    content_type: str
    content_info: typing.Optional[IUserActivityContentInfo]
    activation_uri: typing.Optional[winsdk.windows.foundation.Uri]
    activity_id: str
    state: UserActivityState
    visual_elements: typing.Optional[UserActivityVisualElements]
    is_roamable: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivity: ...
    def __new__(cls: typing.Type[UserActivity], activity_id: str) -> UserActivity:...
    def create_session(self) -> typing.Optional[UserActivitySession]: ...
    def save_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def to_json(self) -> str: ...
    @staticmethod
    def to_json_array(activities: typing.Iterable[UserActivity]) -> str: ...
    @staticmethod
    def try_parse_from_json(json: str) -> typing.Optional[UserActivity]: ...
    @staticmethod
    def try_parse_from_json_array(json: str) -> typing.Optional[winsdk.windows.foundation.collections.IVector[UserActivity]]: ...

class UserActivityAttribution(winsdk.system.Object):
    icon_uri: typing.Optional[winsdk.windows.foundation.Uri]
    alternate_text: str
    add_image_query: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivityAttribution: ...
    @typing.overload
    def __new__(cls: typing.Type[UserActivityAttribution], icon_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> UserActivityAttribution:...
    @typing.overload
    def __new__(cls: typing.Type[UserActivityAttribution]) -> UserActivityAttribution:...

class UserActivityChannel(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivityChannel: ...
    def delete_activity_async(self, activity_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete_all_activities_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def disable_auto_session_creation() -> None: ...
    @staticmethod
    def get_default() -> typing.Optional[UserActivityChannel]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[UserActivityChannel]: ...
    def get_or_create_user_activity_async(self, activity_id: str) -> winsdk.windows.foundation.IAsyncOperation[UserActivity]: ...
    def get_recent_user_activities_async(self, max_unique_activities: winsdk.system.Int32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[UserActivitySessionHistoryItem]]: ...
    def get_session_history_items_for_user_activity_async(self, activity_id: str, start_time: datetime.datetime) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[UserActivitySessionHistoryItem]]: ...
    @staticmethod
    def try_get_for_web_account(account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> typing.Optional[UserActivityChannel]: ...

class UserActivityContentInfo(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivityContentInfo: ...
    @staticmethod
    def from_json(value: str) -> typing.Optional[UserActivityContentInfo]: ...
    def to_json(self) -> str: ...

class UserActivityRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivityRequest: ...
    def set_user_activity(self, activity: typing.Optional[UserActivity]) -> None: ...

class UserActivityRequestManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivityRequestManager: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[UserActivityRequestManager]: ...
    def add_user_activity_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[UserActivityRequestManager, UserActivityRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_user_activity_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class UserActivityRequestedEventArgs(winsdk.system.Object):
    request: typing.Optional[UserActivityRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivityRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class UserActivitySession(winsdk.system.Object):
    activity_id: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivitySession: ...
    def close(self) -> None: ...

class UserActivitySessionHistoryItem(winsdk.system.Object):
    end_time: typing.Optional[typing.Optional[datetime.datetime]]
    start_time: datetime.datetime
    user_activity: typing.Optional[UserActivity]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivitySessionHistoryItem: ...

class UserActivityVisualElements(winsdk.system.Object):
    display_text: str
    description: str
    content: typing.Optional[winsdk.windows.ui.shell.IAdaptiveCard]
    background_color: winsdk.windows.ui.Color
    attribution: typing.Optional[UserActivityAttribution]
    attribution_display_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserActivityVisualElements: ...

class IUserActivityContentInfo(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IUserActivityContentInfo: ...
    def to_json(self) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.Playback")

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx.direct3d11
except ImportError:
    pass

try:
    import winsdk.windows.media
except ImportError:
    pass

try:
    import winsdk.windows.media.audio
except ImportError:
    pass

try:
    import winsdk.windows.media.casting
except ImportError:
    pass

try:
    import winsdk.windows.media.core
except ImportError:
    pass

try:
    import winsdk.windows.media.mediaproperties
except ImportError:
    pass

try:
    import winsdk.windows.media.protection
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui.composition
except ImportError:
    pass

class AutoLoadedDisplayPropertyKind(enum.IntEnum):
    NONE = 0
    MUSIC_OR_VIDEO = 1
    MUSIC = 2
    VIDEO = 3

class FailedMediaStreamKind(enum.IntEnum):
    UNKNOWN = 0
    AUDIO = 1
    VIDEO = 2

class MediaBreakInsertionMethod(enum.IntEnum):
    INTERRUPT = 0
    REPLACE = 1

class MediaCommandEnablingRule(enum.IntEnum):
    AUTO = 0
    ALWAYS = 1
    NEVER = 2

class MediaPlaybackItemChangedReason(enum.IntEnum):
    INITIAL_ITEM = 0
    END_OF_STREAM = 1
    ERROR = 2
    APP_REQUESTED = 3

class MediaPlaybackItemErrorCode(enum.IntEnum):
    NONE = 0
    ABORTED = 1
    NETWORK_ERROR = 2
    DECODE_ERROR = 3
    SOURCE_NOT_SUPPORTED_ERROR = 4
    ENCRYPTION_ERROR = 5

class MediaPlaybackSessionVideoConstrictionReason(enum.IntEnum):
    NONE = 0
    VIRTUAL_MACHINE = 1
    UNSUPPORTED_DISPLAY_ADAPTER = 2
    UNSIGNED_DRIVER = 3
    FRAME_SERVER_ENABLED = 4
    OUTPUT_PROTECTION_FAILED = 5
    UNKNOWN = 6

class MediaPlaybackState(enum.IntEnum):
    NONE = 0
    OPENING = 1
    BUFFERING = 2
    PLAYING = 3
    PAUSED = 4

class MediaPlayerAudioCategory(enum.IntEnum):
    OTHER = 0
    COMMUNICATIONS = 3
    ALERTS = 4
    SOUND_EFFECTS = 5
    GAME_EFFECTS = 6
    GAME_MEDIA = 7
    GAME_CHAT = 8
    SPEECH = 9
    MOVIE = 10
    MEDIA = 11

class MediaPlayerAudioDeviceType(enum.IntEnum):
    CONSOLE = 0
    MULTIMEDIA = 1
    COMMUNICATIONS = 2

class MediaPlayerError(enum.IntEnum):
    UNKNOWN = 0
    ABORTED = 1
    NETWORK_ERROR = 2
    DECODING_ERROR = 3
    SOURCE_NOT_SUPPORTED = 4

class MediaPlayerState(enum.IntEnum):
    CLOSED = 0
    OPENING = 1
    BUFFERING = 2
    PLAYING = 3
    PAUSED = 4
    STOPPED = 5

class SphericalVideoProjectionMode(enum.IntEnum):
    SPHERICAL = 0
    FLAT = 1

class StereoscopicVideoRenderMode(enum.IntEnum):
    MONO = 0
    STEREO = 1

class TimedMetadataTrackPresentationMode(enum.IntEnum):
    DISABLED = 0
    HIDDEN = 1
    APPLICATION_PRESENTED = 2
    PLATFORM_PRESENTED = 3

_ns_module._register_AutoLoadedDisplayPropertyKind(AutoLoadedDisplayPropertyKind)
_ns_module._register_FailedMediaStreamKind(FailedMediaStreamKind)
_ns_module._register_MediaBreakInsertionMethod(MediaBreakInsertionMethod)
_ns_module._register_MediaCommandEnablingRule(MediaCommandEnablingRule)
_ns_module._register_MediaPlaybackItemChangedReason(MediaPlaybackItemChangedReason)
_ns_module._register_MediaPlaybackItemErrorCode(MediaPlaybackItemErrorCode)
_ns_module._register_MediaPlaybackSessionVideoConstrictionReason(MediaPlaybackSessionVideoConstrictionReason)
_ns_module._register_MediaPlaybackState(MediaPlaybackState)
_ns_module._register_MediaPlayerAudioCategory(MediaPlayerAudioCategory)
_ns_module._register_MediaPlayerAudioDeviceType(MediaPlayerAudioDeviceType)
_ns_module._register_MediaPlayerError(MediaPlayerError)
_ns_module._register_MediaPlayerState(MediaPlayerState)
_ns_module._register_SphericalVideoProjectionMode(SphericalVideoProjectionMode)
_ns_module._register_StereoscopicVideoRenderMode(StereoscopicVideoRenderMode)
_ns_module._register_TimedMetadataTrackPresentationMode(TimedMetadataTrackPresentationMode)

BackgroundMediaPlayer = _ns_module.BackgroundMediaPlayer
CurrentMediaPlaybackItemChangedEventArgs = _ns_module.CurrentMediaPlaybackItemChangedEventArgs
MediaBreak = _ns_module.MediaBreak
MediaBreakEndedEventArgs = _ns_module.MediaBreakEndedEventArgs
MediaBreakManager = _ns_module.MediaBreakManager
MediaBreakSchedule = _ns_module.MediaBreakSchedule
MediaBreakSeekedOverEventArgs = _ns_module.MediaBreakSeekedOverEventArgs
MediaBreakSkippedEventArgs = _ns_module.MediaBreakSkippedEventArgs
MediaBreakStartedEventArgs = _ns_module.MediaBreakStartedEventArgs
MediaItemDisplayProperties = _ns_module.MediaItemDisplayProperties
MediaPlaybackAudioTrackList = _ns_module.MediaPlaybackAudioTrackList
MediaPlaybackCommandManager = _ns_module.MediaPlaybackCommandManager
MediaPlaybackCommandManagerAutoRepeatModeReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerAutoRepeatModeReceivedEventArgs
MediaPlaybackCommandManagerCommandBehavior = _ns_module.MediaPlaybackCommandManagerCommandBehavior
MediaPlaybackCommandManagerFastForwardReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerFastForwardReceivedEventArgs
MediaPlaybackCommandManagerNextReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerNextReceivedEventArgs
MediaPlaybackCommandManagerPauseReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerPauseReceivedEventArgs
MediaPlaybackCommandManagerPlayReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerPlayReceivedEventArgs
MediaPlaybackCommandManagerPositionReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerPositionReceivedEventArgs
MediaPlaybackCommandManagerPreviousReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerPreviousReceivedEventArgs
MediaPlaybackCommandManagerRateReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerRateReceivedEventArgs
MediaPlaybackCommandManagerRewindReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerRewindReceivedEventArgs
MediaPlaybackCommandManagerShuffleReceivedEventArgs = _ns_module.MediaPlaybackCommandManagerShuffleReceivedEventArgs
MediaPlaybackItem = _ns_module.MediaPlaybackItem
MediaPlaybackItemError = _ns_module.MediaPlaybackItemError
MediaPlaybackItemFailedEventArgs = _ns_module.MediaPlaybackItemFailedEventArgs
MediaPlaybackItemOpenedEventArgs = _ns_module.MediaPlaybackItemOpenedEventArgs
MediaPlaybackList = _ns_module.MediaPlaybackList
MediaPlaybackSession = _ns_module.MediaPlaybackSession
MediaPlaybackSessionBufferingStartedEventArgs = _ns_module.MediaPlaybackSessionBufferingStartedEventArgs
MediaPlaybackSessionOutputDegradationPolicyState = _ns_module.MediaPlaybackSessionOutputDegradationPolicyState
MediaPlaybackSphericalVideoProjection = _ns_module.MediaPlaybackSphericalVideoProjection
MediaPlaybackTimedMetadataTrackList = _ns_module.MediaPlaybackTimedMetadataTrackList
MediaPlaybackVideoTrackList = _ns_module.MediaPlaybackVideoTrackList
MediaPlayer = _ns_module.MediaPlayer
MediaPlayerDataReceivedEventArgs = _ns_module.MediaPlayerDataReceivedEventArgs
MediaPlayerFailedEventArgs = _ns_module.MediaPlayerFailedEventArgs
MediaPlayerRateChangedEventArgs = _ns_module.MediaPlayerRateChangedEventArgs
MediaPlayerSurface = _ns_module.MediaPlayerSurface
PlaybackMediaMarker = _ns_module.PlaybackMediaMarker
PlaybackMediaMarkerReachedEventArgs = _ns_module.PlaybackMediaMarkerReachedEventArgs
PlaybackMediaMarkerSequence = _ns_module.PlaybackMediaMarkerSequence
TimedMetadataPresentationModeChangedEventArgs = _ns_module.TimedMetadataPresentationModeChangedEventArgs
IMediaEnginePlaybackSource = _ns_module.IMediaEnginePlaybackSource
IMediaPlaybackSource = _ns_module.IMediaPlaybackSource
